
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python Fintech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']

def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    ...


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    ...


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s*\x00\x00\x00z\x04e\x00\x01\x00W\x00n\x07\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01e\x00e\x02e\x03d\x01d\x02'
        b'\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds[+\x00\x00PYARMOR\x00\x00\x03\n\x00o\r\r\n\t4\xe0\x02\x00'
        b'\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x1b+\x00\x00\x00\x00\x00\x00\xa0O\x88EOI\xea@K\x97\xdaG\xa1\xcd\xea\x19\x00\x00\x00\x00\x00\x00\x00\x00\x19\xfc\xe5\xc6c\x91\x87O\xef\x11\x0ck\x8c\xb7\x9e\xc5ke\x0b:\x1a'
        b"~\x00c\xf9'\xd5\x177:\xcem\x18\xc1\xa9\x8e!u\xbd\x96T\x05\x03\xa3\xf9(\x15p\xecJ\xd8\xda\x88\xe0\xac\x14f\x96\xc9\xd7\x1f8\x8ej8\xec\x00\x15|\xa7\x02\xa8d\x84\x9f\xc9\xb4\xb8q\xb8\x1a:\xcef\x10"
        b'w\x9f \xe9B\x07\x93\xce\xb1\x12M\x88\xa4,\xf2?J\x08\xfc\xcdv\r\x8c\xb2\xceYm\x1fb\xe5\xdeV\xb2\xcf\r/\xf4\x99}\x1f\xc9#\xa9\x86\x80\x08\xaa\x8ca\x983zq\t\x1d\xcb\x1b\x9de\xfc\xa5u\xb4\xf2'
        b'\xc3.\x0f\x13(\xc6CKdz\x0b\x96\x07u\x00\xd7\xbb/\x82\x8e\xe7\xefXX\xfb\x94\xa7\xb8b\xb2\x97\xfc\x92\rS\xe0[0J9\x00n\xa6J\x0b\xeb\x08\x1aRAg\xecOZ\xf3{Q\xf7\xe3\x96\x0fj9\xed'
        b'{\xc4\xa8\xbb\xf7m\x0eN\xe8\xa9\x0e\x1d\xbb\xa9\n\x1f\xbe\xad\x84O\x87~\x8c"5?\x14\x1f\x13\x06\xca\x83\xc7s\x9a\x9f\xd4\xd6O\xbf\xea:\xfci#\xca\xfd\'S"\xe1{\x8e\xfd\xe5a\x06\xd4\xa6\x8c\x8c\xf1P\x1c'
        b"\xcd\xa9Q\x8c\xa2\xecA)\xf7S\x92`\xdc\xdb)\xd3\xb7\xeb\xa9\xd9>%{\xf7\xe6\xd2\xe1o5R\x1e$\xca\xa7\xe7n\xd9\xe0\xa6\x03L\xe9'l\x1e\x9f\xcb\xd5\xe2\xa9\x99\xde\xde\xa5\x079\xbc\x1b\xcc\x04t4\xd2V"
        b'p\x11\x02\x8e0\xb4\x1a+\x17\x10\x8e0\xbc-\xf7m(k\x0b\x8c\xf0\x1e\x1f\xf9\x13r)\xb8F\xcf\xaf,\x1a5)\xe6=#\x0c\xfd\xe75\xe1\xc22\xc7"\xa9\t\xf5\xea\x8b\x8d6\xf2\xc8\x91\x9fA\xbd\xceP\x0b\xd2'
        b'\xcb\xe0:\xa9\xfd\xb0a\xad\xee\x11\xe2\x88 y\xc3\x1e\xc9\x8eY\xb0\xa3\xd6\xa3\x02\xed\x0fb.\xbe**\xd9\x17\xfa^\x19X\x8b|\xbd~\x89\xe0g\xd9\xca\xe5ne\xbd\x8c+\xc1mLT\xa1\xa86)\xd4\xeb\x01\x93'
        b"\\\xdfc\x97\x8d\x8d\xd4\xb0k\xfb\xa5yV\x18cx?\xb0\xad\xa2\x12\xc9j\x13+'\x0c<R'5\xa3\x9f!\xd5i\xa5r\xa2V\xd0=\x97}Y\xfe\x0b\x82\xc9\xeea\xa6\xfc\x15\xc2Fn\x1c0fe\x9b\xd3V"
        b'\xe9\x92\xa4\xd3\x17\xc0\x16/>\n\x9ab\xd2\xc9s~<W\x9a\x18\x0b\xb4uS\x1e\xa0\xc4\xc37\xa0\x10\x81s\xfd\xd4\xe1h\xc6Z\x88 Y\x8e\x10\xd0Y\xe3\x0e=w\x9e7\x7f\xfc\x0en\x85\x87\x1aG\x86\x04\xef\x91'
        b'\xc0\xa6\xe3\t\x0cU\x8d\n\xbd/m\xd9\x07\xabY\xd7\xd1[\xf2\x1eP\xd0\xdd\xb1f\xe3\x17\x04\xc4\x17\xf0\x98\x9f\xbfO\xe9YL\x0f\x9e\r\x9a\x82LZKa1\x94\xc8\xf0\x10\x8e6\xe0\x89{\x8fy\xde@k\xe0\xac'
        b'\x04v\xbf\x14\xe8\x02\xc3r\xbe7\xcaw\xabP\x92\x1c|\x03\xe3C\xbfMs\x0f\x0c?o\xfdQqX\xa6~e\x98\x84\tI\xcf\xbf\x1bB\xb4?j|\xfavxS;Nx\xbaB\xa0\x10\xf3\xc2Ag\xe4z\x1d'
        b'\x9a\xf0\xbdiY&\xecY@\x8eA\x82*\x99\x8d\x030a\xd7\xd6f3\xadI\xe91\xed-\x04\xc8_\x08>`\xad\xd6\xc8\x1ej\xff\xf3Y\xa2\xde\x8d\x10\xc7y9\n\x8bI\xdc\xd6\xc4\x80\xeb{\x01\x14R\xd2 \xdf'
        b'\xf9L\xea1.\x9f&\xc7\xb2W\x84v\x01\xe4\xfd\x02 \xf6\xd9\xf1\xe4H\x13\xa1\n\xd8\xf9\xeb\xbf2\r\x8c)\xa3}\xdc\xd9r\xf6E\xb6\x19\x0fp\x95\x9dZ_\xe76KX\nH\xfd.s\x02\xf3\x04\xda\xe8os'
        b'N\x16\xf8\xc4Waw\x9eZ\x95\x86\xeb\xaaX\xd3\xbc\x9d\xcd1w9\x17\xd1\x15 C\xae~`\x99\xc2\xf4\x1c\nK\xc3\x1a\x9d72\xf5\xdc\xf1,\xb2>\x8e\x1fA\r\xee\x94{X\xcee\xb4\x86\xa6\xd3\xae\xcbto'
        b'\x83_\x85\x14\x1f\xec\xfe%}\xe3\x8d\x1a\xf8\xb6\xa8\x7fWiJ\xe6j\xba\xea[\xf6(\xcb\x03xf\x95\xdfKh\xf5x\x1e+\xdd\xdeK\xc0R\\U>\x08]1\xb6\x91\x11\x7f\xef\x16K\xb0f\x0b\xa1\xdcZ\x84\xb7'
        b'\xacZ.\xa7\xa4\xef\x11M\x93}A\xb3flW(Y\xf5\x17\x0f\x17C\xda]\xe6\x99\x97\xaf\xea\xd9K\x7fGVt\x86\xd6)\xb7\xfd\x1f\xb4*\x104\x1f\xd4\x91\xc7\xf3\xd3\xcbTI[\xd1@\xd27\x98\xa0\x026\x05'
        b'\xb0bX\xcd\xbbzKE\x89Wa\xee/N\xf6\xe2e?\xee\x11\x8dvTY;\x7f\xe9\xb7\x1e\xde|xB\x14\x97\xde\x11\xc8\xb7\xbc\x92\xaa\xad\x04\xba4lpUe\xae\x87\x85B\x93\xe2)\xb1e\x11O\x07\xa2\xfd'
        b'\x92\xef\x0e\x9f/\x8a\xfd\x7f\xee\x85\x8c\x86)dNJ\xed\x08\xac\x1b\x8a\x866=\xd1\x94\xbf\xe6\xb0gzq\xa1\x7fh\xf3k\xbeE5\xfa\xdb\x0b\xe8\xe8\xc3\xc0\xa7E7k\x13\rf#\xe3\x90\x19Vx\xf3\xcei\xac'
        b'K\xd4\x04\xdaE-\xfe\xf7\xe8\xeb\x00\xae\xbf\xa4vN\xdc\xdc\xd2\xeb\x0c\xe1z/\x11\xcd\x12,X\xd0w\xe3BJ\x9f\x9d\x95#}E\xc1j\t\x86\xa5\xd07\xd6?\xef+q\x8fG6\xcc\xbe\xf4R\x12\xb6>\xcc\x86'
        b"\x86?N\xaa\x84\xeb<\xf3;F\x92\xe1\x1cIDQ\x9b?r\x93a\x9c\xba\xb7\xd1'\xb7\x03\x84\x07$.\xd5\x11M\xb0mR\xe7*\x9e\xacJ\x95\xd6\xe7\xe0\x18R\x98Zo\xa1\xdd\xb0\xacpfI:\xb8\x04M<"
        b'\x90\xbeaM\xfd\x9d\xea\xb1\x19P\xdd\xa2\x11\xf2\x9b\x84V\xdb^\xddGSV\xae\x1d\xb1o$\x93\xbc\xe0\x03\xa0\xf0RX}"\xe3\x8c^9\xd7eG^+\x00\xf6\xbcR\xcd\xc1\x85\x1b\xc7Y#Q,"\x1e\r\xb5'
        b'\x80\x01#\xdb3\xef\x8c\xa3\x12v\x8a\x16a\x14\xfb\xe4\xfe\xee1\xadZ\xce\x1d\xb6 \xd6\x84\xae.\xe1\x81{6\xcci\xb2\xc3\xb1\x9e\xca\xb1\xd3\xbf7e\x9bZ\xfd\x1b?\xab\x9b\x1e\x1e>\ro\xa5\xb3\xbb\xd1\x02\x9a\xe8'
        b'\xfb\xc3\xfd1k\xd5\xe6~\x14\xc3\x93\tr\x08\xa2\xc2I\xee\x99\xef\x1e\xf7\xe2\xec|\x904\xe7!\x15\xe9z\xa7\xa8\xcbC\xb6m\r\xae\xb2m\nJ\xee\x7f3\xc1\x99\xa4h(!\x85\x11VW\xc9w\xbb\x9e\x8e\xd3\x1d'
        b'\xad\xe7r\xf4\xce\xd9\xfd\x1b$:{?\xbdc\x85L\xa0\xf9\x85\xd5\x0e\xdd\x1b\xaf\xd8\x13\xe0.U\xfe\xcaAu*\xd8\xbf\x96X\xd2\x869\x16\x8b\x1d\xdb\x16\x04\xe5\xe6\xca6\xbb  `\x12|\xef\xeb\x03:\x8cR\x86'
        b'5_\xba\x06\x85\xc4\x08B\xe1\xdd\xf2\xc2\x9c&C0\xcb\xc5S)S\x13F\xce%\x8b\x89\x9e\x9e\xfd\xbe\xd9p+\x05\x8f\xa1\x0cz\xd6cmg\t8\xb7\x8b\xf3\x03c\xec*\x84\xe3\xdd\xa0\x9e\x88\x92\xb3x\x0b\x9c\xe0'
        b'\xcc\xb2\xef\xac\x7f\x0f<G5\xe3\xe7\xbe\xaf\xb6\x84\x97;^E\xb3\x08\x9f\xcbn\xa8\xb0\n\xccH~\xaf\xac/\xf3\xe7\xffu\x1b\x91\xca\xce\x0c"\x0e\xb6u\xf1I\xa8\x02\x03\x90\x84\xc9\x87\xc4n<q\xb4\xb6\x92\x8d\xab'
        b'$"q\xedTEuF\xa3\x93\xc1\xb2s9\x82\x17\x89<:\xd6\x89\xfc\x01\x9b\xc2%z&gI\xbe\x1e.\'\xcd\x92\xc5;O\x81\xfc]W\xccx\x1a\xd3X\x0e?3\xf4\x1b\xd4\xc9Ei\x88$\x0e\xe1\xd3\x8f)'
        b'\x17\xdf\xbcl\x9a\xac\xdcPLK\xdd\xbcx\xf6\xdf\x0b\x1f\xcd&\x88\xd9r\xf8\xa1\x9b}\xa6\xa9\x0f\xea\x18\xbb\x12\x94GA\xc7\x1ey\xaeO\xcb\xf2\xcd*P\xbc\x12<\xaf5\xf1\xeag(\xdf\x97\xb0\xe7x0H\xa9\x9c'
        b'\x85+\xb2\xcc\xe0\xbd\xa1\xeb\xef\xfe;\xa0c\x80\x90Cw\xb3HZ\xfd\xf8\x1a4\x8dj;[\xcf\xb2\x88Q\xc1O\x0b?\xa5\xe3Pw\x11\x1a\x9f\x00J<\xd9-\x16\xb2c@\xa3\x08\xa4\x96\xf5.wJ\x13\x1d\x9a\xd5'
        b'\xfa4\xf3\xfa\xdd1\xe5\x12<!\x96\x15f;\xe1\x85Q6\xd8\xc4\xb9E\xc3\xf90vA \xd1O\xef\x0f\xf1\x19\xdfnC\xce\xbb\x99\xd8Zz\xa3jC\xa5[\x81\t<\x8c\xcc%#\xab\xf6\xb8U:\xbb\xaf\xebG'
        b'\x01\xb1\xc2j\xc4\x0fV\x94\xe2h\xcb\xac\x8ak\xbf\x93\xe6\xaa\x9fw\xd0@Hc2\xc0\x9d\xffM\xdd\x8e\x94\xada\x00@8Y\xc3\xc5<\x89\xee*\n\xd6\xba\x9fH+\x15\xe5]\xd3Vm\x18\xf3\x078T\xeaU\xc9'
        b'\x89\x8df\xa2\xc3\xd0\x9a\xe3a\xaa\xae\xe6\xae5\xcb\xed<W9j\x92\x8f\x8c\xc4\xaa\x92RT#u\xdcC\x81\xf7t\xfc\xea\xf3\xb3N\xe2\x8e*J\xec\xca\x1fN\xeae3B\x88Y]`+\xcb\xac@\xbcTF\xca'
        b'\x0es\xbf\x8c\xa5\xcfq\x88:D\xf2W\x8b\xbewZ\x7ft\x97@\xe5bs<RD\xcbVW\xd0\xff^\xa3\x08i\x86\x11\x16\xcc\x08\xf0\x0f-\xd6\xea7\xb5v/\xb7\xc3\x86b\xea)\tnO*\xd4\x93#\xa4\xbe'
        b'.\xdb\x13}\xa7<\x8fI\x19\xc8O\xda\xad\xd0{<\x91\xba\x82\xca\xfc4\xbd\xeb:\xea\x08\x13s\x15\xb4\xd8\xaaU\xa1\xbbi\xb1\xe3k\x94\xef#\xd4\t\xd5\xd6b\xa5\xb0aVz\xc8\x7f\t\x01*\x88\xc9\xfe\x15\xa2D'
        b'\x9b~\x8a54\x0e\r\xd8\x05\xd1b\xccQf\xb8\x9d\xdd\xdd\xf9^\x82\xcd0\xb6\xaa\x9b\xf6\xfa\xfb\x97)5\x8cx\xe7U\xb2\xff\xf17\xea\xb4\xb0\x02\x99Ir\xae\xd7tm\xce\xb74N!y;{v\xc0t&2'
        b'\x0e\x01@\xbf\xdd\xb0\xd3\xa0I[\n\x1fa\x00C\xf1\xbc\xe7\xb0 \xd5\x80V\\\xfc\xfcU\x1f\x8c\xbdB\x10+j\n\xaa-\x0fO\x8bL\xb8)\xa1\xe7`9\x984\x1e\x18\x1cd\x914jf\xef\xf4F\x8e\xad\x91s'
        b"h\xe5JL\x98x\x88V`R\xd3z(\xf9(a\x9e\xffr\xd6*\xed'\xd3\xa1\x8a(\xb7\xd8\x91\xc1\xd16\x02\x10\xaaYy\x9f\xa6\xfd\xda\xae\xce\xf3\xb5c\xa7\xb1\x82\xd9\xect\x1f\xd0\xaaL\xc7\xa9\xc7V\x7f\x9dL"
        b'L\xfc\x9a\xa0]\xbb\nM\x19\x1bP\xb7\x96\xedk\x02\xa8\xfc\xa5\xc6\x1b1\xde\xf9\x7f\x04@\xf0\x9a+\xb2z\xa7$\x8b\x0fmcE\xc0\xe9j\xe6\xb3\x08\xc3\xadn\xf7IK\x90\xaa\x11\x07\xd1\xad\x8aU\xb9\xdf;,!'
        b'\x16#\x83S\x9d\xf2\xfb\xec\x0b\x1c\x11\x98K\x1eM\x9eN\xb3\xe8n\xe7\x17u\x0f\xf8\xe7\xcb\x94!\x00\xee\xcf\xb7V\x95\xfd\xb3\xdf\x81\x13\xe1\x13\xb1\xf0o\x07\xa3\xbe\xe0\xa7\xc8\xb0\x99\xc1\xddG\x0c\xb6M\x80\xf5\x95\xdbJ'
        b'X)w\xa6"=\xdbm\xe3\xb3k\xfcx46.\xba\x88\xdal\x89\x16\x83\xa6\xaa\x7f9\x94~/\x14X\x18Y\xb6\\\xd8\xebz\x99\xcf\xf0\x18\xd7\xc2\x0c!e3\xa1l\xf2P\xe7\xce\x15\x1fDX\xbdP\xedw\x1f'
        b'\xcd\x19Lh1]\xb7\xfb6wjh/p\xef\xcf\xc9m\xce\xf9\n\\\x8d\x83\x8a\xa5\xafd\x97\x11\xcb\x9f\x9cds\x04\x86\x87f\xb7\x17\x90P\x12wJ!\xaf\xddy\x98B\xb4\xc0BP\xda]\xa86\x1a\x84\x0b\xcd'
        b'ox\x89\xa9\x85sF\xe8&\xba\x07\x8d\xc5\xb3\xdeu\xeb\xb2\x90\xf3\xf21Hl\xcc\xcf\x17v\xa3O\xedDQ\xb7\x17\x07\\\xd4W!\xcd\\xc\x142\xbd\xba\xa3d\x95\x7f\x94\xef+\xbc\x90\xf9g\x06\xd4\xd7\x14\x88'
        b'\x98ze\x1aHw\x98\xfbDN\x16\xc34\xa3\xa6;\xd9B{HL\xf6\xfa4\xfe\xaf\xb2\xcc:B$\x08\x17<Fh\x04=z\x0e+\x19+\xd9I\xff\xe5{e\x96g\x1cPl\xb9\x8b\xf3\x10@s%B\xb3\xb6'
        b'\xc3g\x7fq\x82\x1a\xf5\xb4\x18\xa4S\xb2\xf5\xfftz\xf0\xc6\xce\x08\xda\x83\xb6\xe0)\xb4\xb5\xe7.\x05|\xa9\xb3,2\x7f-{_?<\xdb\xd6Wb{ \xd6\tj1\x05m\xe6\x92\xc7`L\x0e&@\x03o\x86'
        b'\xf9\xe1\xab\x8d/\xe6E\xea\xe29\x0e\x9b\x0c;,\x1dEa\n\xb9/\xe9\xd2\x1c\xeb\xe9\xf7\x00\x93/\xa8gl:\xdb\\\x9eG\xfb}\xfd\xc6v\xe6\xfcY5 \x81\x8d_\x10SO \x87\xbd\x13\xc4\xc4\x04\xd5b\xbc'
        b'\xffm\xe7F]\xe5\xb5zN\x148\x85\xcd\xedB\x0f>\xberF\xb9\x88C\x0e{\xc4[\x8f\xf6\xe0\x9aB\xe0#I~1>\x97t\xb3\x95\xbf\x9c\\8\xa8\xe31AT\xa9\xb06\xfcF\x8611>\x88\xe9\\\x8a'
        b'\x16\x9f\x02\xd2\x8e\x99j\xc2\x8b\xc6\x9ev3/\xf6\xdb\xa1\x90\x9fp\xdbkC\x03\x16\xda\xde\xc9\xd3\xe5a@w\xb1{\xb5eM\x1bO~\x8b\xd9\x9d|^bE\xa5\xe3\x80MV\xcdg\x8a\xb9\x14\x07I\x12\x0fF_'
        b"!\xbfk@p\xc8\xef\xf8\xeegT\x8c\xe8<\x95\xb7\xa0\x01\x00}\xae\x88\xd2Q\xce\xf3\xa6\x13w'\xa8A#\xb3\xbe\x15\xfa\xdco`\x19\xec_\xb2\xea\xc4\xb4\xbe\x87\xed=\x8d\x818~\x9e$/\xaa\xc7cjc\xab"
        b"7\x89\x0b0\xe1\x00\xd7\x8a\xf3v\x9a\x88\xc5\xad\xb5\xbcHkJ\xdb\x036\x08.\xfd.\x87\xfaa=\x9a\xe4g\x11\xa6'{\xf1\x9e\xee\xcaL\x02J8\xed\x89y\xcd\x05L\x96\x86\xb6\x0c\xc3\x96\x9d\xdd\xdd\x99\x81\x0f\x94"
        b'\xf0\x92\x8e\x99\xf7q\xc8j3\x9f\x13wr\xc9\xd0\x15\x98\x1b\xc6r\x97o~\xb1\xb1K8O-<5\xc9\xb2T`\xeb\x8a\xf0\x87i\xbe\xc9\xc5\x02\xbds\xf1\x05\x7f\xcd\xab\x12\xf3\x15&k6\x9d\x96\xe4\xc2\x0f\xed;'
        b'mj]\xa8q\xae*Wg\xe3\x9f\xa6\x1f\x06\x0bf\x89,\xca\xcaU\xc4\xed\xf1/\xdb\xb7cPe]\xcd\x94\xe2^\xe5\x19\xdd\xa0\xf1/\xe5\x83lZr\x808\xf9\x94n\xdeF~7aU\xcf\xe1\x17\xa8 f\xbe'
        b'c\x993\xfaX0\xa5\xbcDQZ\xd0\x05\xa0V|5!\xe0\xcb\x1e\x07$m\xf1D^\n8\xeb4]h\x98I\x9d\xda\xca\xde\x1c\xef@Aa\x00\xe3\xb9\xfd\x0co\xce\xab6d=\x82\x14\xa6\xeb\xf3{+\xab\xcc'
        b'fa\x8de\x82\x18#\x90\xafAq\xa2D\x89q(\xc9\xf2\x08\xe7d\x17\xdd<\xfd\xae\xb0\x95\n\xba\x83\xc7<(\x80\xd6\x98\xbc\x9d\xea9\xf9\xdb\r7z\xf0k\x1d\x15\x02(UM\x0c?\xdb/>y\x14\xb5\x00f'
        b'\x1f\xbf\xefInF\x8b\xb1\x9bOv\xb9\x17\xe8\xa0\xe8D\x87\xb5np\x1afU\xa9\xb0DX\x94\x17H\xe2\xba\xf8\x88\xef1\x8dT\x84\xdafs\x02[\xbfF\xf5@\x9e\xb8b\x7f\xef\xb3-Y\x12|!*\x85\xc0='
        b'\xca\x07\x90\x8aD\x91DE\x0c\xbcpW\x9d\x9a\x0e\x1a(\x80\x15N\xd7\x06\x0f\xa2-\x1f\x1d2\x96~\xc6v@\xf6\x86h\xe3[\xc1F\xb7\xfa\xe3\x9e\xf7_]\xdb\xf1h\xbd\x1dZ\xf0\x8d(l\xf6\x8e#L\xf6\xe8z'
        b'\xd9\xcbn\xe0\xca\x9b\x07\x0f\xc0B\x81<\xb0!,\xf8B\x14\xde\xa3\x08\xe3\x08\x00\xec\xc3\xc1\xdeh8Hq\xbcO\xdf\nF\xf19U\xb3-\xa6R[s\xc9\xb5\x08\x1a\xa4\xea\x7fg\xe4\xd4\x1f\x06\xca\xfe\x05_7%'
        b'+]1\xe5\xd3\xdf8\xe8svmQ\xab\xb6*\x1fZ\x1bj\xfe\x8a<\xf4\xf4&\xc3\xd2.\xa5CEW\xa9\x96\xe9]u\x96\r\x0c\xbbNHz!I\x9d\xc3u\x9a\x0erp\xdeb\xc8\xa7\xe8|\x7f\xdd\x10\xb2"'
        b'\x83\xea\xc5\x17#\xd6\x82oSn\xc50\xb4Io\\\n\x8c\x12\xbf\xf9\xf8F\x00\x807B\x0f\x96\x15\xdci\x04\x90@N\xad\x01~\xa6I\xaa\x0e\xf5\xb2P\xe7\xec\x07\xe9Y\x9aR\x081\x17{8v\x86b\xf0\xbeU'
        b'\n\xd6\xd9.v~\xe1@Q\x08%5\xde\x82[4?+sFsB\xa8Mv\x93\x98g\x1b6L\x83P\xc4\xfb\x86\xbd\xcb{\xf4\xc2\xfa/\xd8\x8e\xe2\xe8`\x1dV\xc2^[\xa2\xa5N\xb2\x10~\xdcY\xae\x1d\xca'
        b"\xcer\xde\xc2\xc7^++i\xdaq\xd9\xf0\xa21\x0b\xce\x8aB'\x0c\xb39;@W\xaa\x88\x8a\x07]\xda\xf31\xbf\x8d\x91\x93\xef\x9c\xb8j\xd3\x19\xe5\xbb\x0bw\x8c@X\xd7P\xc6\xa4\xcdW\xd0FQ\x1dQ9A"
        b'\x8a\x1c\x02\xfe\xbd\xd58{&\x92\x1a\xd0/\x01\x1b\xd2!\xc9\xad\xd3p\x16\x1b=\xf5\xd2=5\xde+e\x1f\x83b,p \xad\x16\xd9\x13\xeaQ\xe1:\xea\x95\xeaZ5*_$\xbc\x94\x9c\x8e\xb3S\xbc\x02\xbc\x8d~'
        b"\xe2\xcd9\x8b\x9a}\xd9cQ\xa6I\xae\x17\x81X\xb5\x0b\xc9K\x16\n\xfd\xb3%\xaew'\xdf\xd3S\xa2&XK\xe1q\xa0\xb2\x8a\x92\xfe]-{\xaf!\xe3\x16\x05\x96\x0bO%m\x86:\xb1\xa7\x1e\xe2/\xba\xa2B"
        b"Ve\xa4\x1d\xbd\xcb\x8f\xd9\x81\xb1\xac\x9cc\xbf\xa4_G[\xf1<nx!\x93\xd4\\\x9b\x83]I\xd6\xdd\xce\x14\x83\x17f\xb7P\x86\x9baq\xfeM]\xd6\x9a\xe3\xab\x90O\xfa\x84\xf6\xe9\\\x9d\x01+\xa6'&N"
        b'U\xd9!\x18vK\xfb\xa0\xc1x\xd6\xd7`\x8f\x05\x0c\\|L\x90\x11\x96j\x17zV\xecbX\x97$\x9d\x00\x9ei\xa4\xbd@\xfc\x0e\xbb{\xc4\xca\xc9\xd1\xcdL\xdd(;q\xce\x1f\xfa&\xaeuJ\x13\n\xbd\xbf\xb9'
        b'\x98\xeePY\xd6\xbc\x9c;\xc8\xd5C\xde\x8ar[\xee\x12\\\xfc\x8bD\xe51\x03\xe2\xf7t\xf0\x7fZ\xb6\xa9\xbd\xab\xc2\xbb\x13\x8a\xde\xef\xea\xbb\x06\xa5\x90\xf5\xc9\xf5^\xf3\x1c\x1eQW\xf3\x7f\xc2\xb7\xafD\xf0\xccf\xe8'
        b"\xfbN\xf5\xb7w\x81\xdb\x11_\xa0'\\\x15M\xf0\xaa\xf1h\xeb\x92<JJ8\xc2^\xceZ\xb8+\x13\x9f\x8e!\xc4\xf7\xdf\xd9\xe9\xeb\xfd\x94\xda\xf4\xf0\x9e]\xca\x15\xa1\xa4\xc9\x1b\xb2b\xc3\x90\x13\xc7\x9d\\7\x84\x99"
        b'\xbafOd\rs\x8a\xc3\x88\xd9\n\xc5bS\xc4sS\x95\x18\x03\xa1\xe7\xa1\xa7t\xd9\x9e\xd6\xe0\xbd\xd1)\x07\xc4\xd02+?\xa9@N\xc8;vQ\xd6\x06\xc0\xb2\x8e\x84:3\xdah\x8c\x0e\xb4\xf4XG\xa3\xda\xd9'
        b'\x90\xeb\x8d\xaf\xd4\x92\xbd>z\xba\xf31\xd4\xc90\x11\xe8G.C\xc2\xfcwM\xa5~\xfe\xf2\x1c\x88}\x8b\xe2y\xf13\xc3\x1dth\xcc\xe8k\xceI\x02#\xa4\xbcw\x06\xd540\xce\x02\xcd\xba\xb9?\xa4*c\x1c'
        b'\x00\x0e\xbf\x8drY\xc3\x05\x16a\x0b\x84\xaf\x900}\xeb\xb9\xbb\xe0]\xd1B#x\x82\xda\xaago\x02\xa45\xf9K\xc4\xe7\xab\xf0e\xbf\xb3\x05\xed.\x9dSS\xa7\xe1\xc7#\x82\x94\x06\r\x12x8\xa1\x17l\xc8G'
        b'\x9f\xe4#\xab\xf8\x07K!\xdb:\x9c%>\x7f\x1761\xd2U\x1f\xd7\xe7\xf4\xfb\x8f\xdd\xa8o\xa2\\\xd3\xac\xb5\xa8\xb4\xc0\xac\xb8\xd5\xec\x80\x83/\x01\xb6\x0b\xb1\xba\x90\xf3<{\x85\x16I0\x04\x06.l\xe6U\xa7\n'
        b'\x85\xd8\x1f\x80\x8ab\xf8\xd3\xa1{\xf5\xc2\x8c\x9e?\x1b\x84\x15\x94\xfe\xec\x8b\xd2pl\xfe\xd7?\xdd]\xea\x98\xf8y\x1fc\xee\x12\xfa\x95\x01z\x15\x9dlc\xec\xc8\x04\xc5-\t~?\xef\x83Q\x9b\x99^\x8f\x8d\x92-'
        b'\x87[[\x16r\xe01\x7fopNu\x8cl\x8a\xa4\xa2\xc8\xb6s5F\x18Y\x18\x97\xae\x8b\xdaq\xccH\x17\xdf\xb7\n\x1f=U!\xac\t\xd5\x16\x1a\xed~h\xbb\x9a\xf8;\xcfH\x1d\xfe+D\x0b\xaeb}[k'
        b'I\x9f\xe7\x0e\xd2r\xf9\xc2\xbd0\xa2\xd7\x1cu\xd3b\x95o\xad\xf1u\x9e\xd0\x8d\x07\xd7~\x80\xa2\x8b\x8e\x16\x0e-\xf5\x86\xd0\xe8\xb8\xe4\x15\x0e\xc9-}OgEx\xec\x838\xf8\xb3\xaff\xfa \xbf\xa0@\xc2\xc2\xdb'
        b'\xe9\x96I\xea\xce\x94\x89\xc8\xfcp\xb3\xf84\x122\xf1\xc0z~\xdd\xb7>\xa0+EB\xe7\xd7\xb2_\xbdH\xb1|\n\xebm\xe3g\xdf\x19(\xe3qp\xb7\x04_\xfe\x81\x94~H\xe2=\x9a\xd1\xe0\xbe\xed[u\xf8B'
        b"\xfc\xa9\x8aa\x95\xcf\nn\xed,\xd5\t8\xd0\x1e4\x14#\xb1\x8b\xbe\xdc\x07\x90\x03K`\x85,\xb2vD\xa2\xab\x90\x8e\xeb]\xba\xdc]\x1d\xc1\x17\x88\xfe\x80'|R\xaf\x9d-\xb9\x87C\xd3\x90\xce\x0bR\xa6\xb8\xbc"
        b'\x05\x00\xada\xbe\x8b\x06\xa5\xfa\xbd2\xd1\x90=\xd0\x84\xab\xb4c\xad\x1b\xb8\xea\x94 \xcc\xcb\xdd\x18o\xab$s\xab\xf2\xe5\xd7\x9a\x02\xf1GX6u\x05!\xae9-\xdc\xa8p\x99\x1a\xfd\xfb\xc0\x9c\x1f$\xbf\xf2\xd7i'
        b'e\xe1\xd1~\x07:\xfa.\xbe\xf6\x07\xbd\xdb\xf2\xdb\xe1\xb0\xd8\xc7\x91t\xf8\xdb\xcd\xac\xa2}\x04\xbf\xc0\xf5\xd4qkj\xad\x18\t\x93u\x154NQ\xc7i23\xd9Qw6\xa1\xda\x8a\x1b\x84c\xad\x1c\xb9\x95\t\xde'
        b'\x0e19\x08\xc3\x14\x9cg\x11\xfd`A\x114m\xf6\x18w_&\xa4IrM\xb1\\\x1c\xcf\xc5\xe0\xb6h\xb0\xceS*\x02\xd5\x97.\xaf\x83\xc3\xa0(=\x1fKs\x8c\x02\xf8\xd3\xe2\xa6\x94\xe8\x11)jM\xbdt\x17'
        b'A9\xc0\xc3u\x83\xee\xdb\x7f\xc2d\\\xb9+\xab%\x9935\xc6D\x99\x8e\xbfAuX\xdc\x88\x94\xb2\xe6\xb3\xb8g?A\xf4\xf8\xf5\xa9\xd4\x9e\xbeg\xdcsK\xde\xb1[\xc7\xbd\x86\x8e\x18%\t\xe4\x14i\xe7\xa8\n'
        b'\xbd\xa0}N\xcf\xd3d:E\x0c\xa4\xaf\x87\x7f^\x8bgB\x08\xc9@\x14\xa5\xefh\xd5\xed\xd6\xc8"\x13\xd0\xbc\x99G\xbaq\xd9\x90:n\xdc\xc9\xdd\xe7{\xdb\xf76\xb3h\xfb\xb9\x1b\xe2_12\xa2\x08U\xac\xa0\xa2'
        b'\xcd\xed\x87o\xbb\xfb\x98\xcfb\x969V\xdf\xca\x03i\xb7J\x90\xa0j\x15\xa3I,\x1e\xaf=\xd4\xa2\xad\xde\x03q\x9c\x12\x1fM\xad\xceBx1\xb9\x00\xe2\xbf<N\x18\x0b\x16\x00\x9a\x9a\xd6\xfeu\x1a$\xc9{`\xeb'
        b'\xec\xc5>\xdb\x1bm\xcd2\xc2AN\xdf\x08\x16\xc4\\\x1f\x95\xd4\xbf\x1aQ\x8d\x84\xf7\xeb\xce~vM\xd4\xbb\xd8F\xd2\xf1,\x96+\x16\x93\xc9\x92\xda\x07S\xb24d-a\x88^`D\x84\xf7\x00nFW\xf4\x96\xcc'
        b'\xa0\r\x9b\x90\xb5M\x9e(\xcf\xdc\xd1\xca\x81,\x9fv\x07g\x87\x0bR\x16\x84\x1c_#\xa5^E\r\x96\xae\xbe\xc1R\x0c\xe6w\x04}\x02\xd8el<\xef}\x9c1B(mI#\x99\x7fv\xed` \x96i\xd9:'
        b"\xd7]\x15\x92\xdd\xd3\xd4\x08+]8\r\xa9K\xb1\xc1^C'C\xe0\xc7\x13\x9c\x8f\x12\xfa'\xa1G\xbb\\\xc3\xb7\xfa\x19&\xc8J\x06\x0cG\x83\x93\xf7\x07\xbdb\xe4\xc4\xa3\xe0a\xe8\x02\xa4u\xb3]\xe6JM\xc5\xe3"
        b'\xfb\x849\xf5\xb1G\xf6\xa5O\x10\x90\x01Oc\xb2\xa1\xdc\xc3q\x18\xe5\xc6\x08~\xf7\xac3.\xcdX\xde\xba\x8e\x8a\x818\xc3Im\xfa\x14Xf\xbfs\xd5\x84V\xde\xaa6wr\xf3\x03p\x99\x85\x9c\xecM\x8e\xea9'
        b'<H%G\xf3\xe96\x08A\xb9\xd7\x8b\x94\xb7\xb8\xc1\xb1\xec\xca}\x0f\x95\xa0\xc2\x82^\x9fv\xa6\x0c\xcf\xfa]\x86\x19\xf2\x99\xef\xacJ\xd5\x87I_\x95\xb0\x1c\xf7[:\xfc\x04C;\xf9\xa0\xf8\xcc]\xf2s}\xd5\xb5'
        b'\xfa\xc5\xed\xc6ab\xc8a\xd5\xa8L\xef\x8f\x81\xd1!H\xafz\xf55SA\xa4ie\x98[\x83D\x1c\xa7D\x87\x98TBu\xa8`\x1f&\xa2sMJ\xbb\x13}W\x82\x10DV\x95\x1a\xc2%\xa0nO\x14+\xf2'
        b'@\xc4I\x89\x91@D\x97<\xf9\xd0\xeag%\xdcB,\xc6\xb1}&sVP$+\xd5^\xe0z\xec\xfd\xb5\xc0%}\xaa_\xf9y.nC\x1e\xae\xe6\x15z\x9a_\xb4\xfb\x19\x8d\xf72Q\x90\xad\xaa\x9b\x93R\xa1'
        b'\xd7>\x82H\xdf\xea1\x16\xa4v`\x8eH!\x81\xd5V\x0b\xa8\x85\x9eZ\tW\x15\xd1\xf3\xb2"\x91"\xfa\x8dav\xba\x82\x98\xfc\xf4\x8c\x06\x8b\x81m\xc3\x93\xaaH\xce-\x08U\x1f\x18\xd1\xa2?\x1e\x8f\xb3}}\x1d'
        b'*\xcb\x1a]iu#L\x14\x83|\xc2?\xdc\x8a\x1d\xb3sV\xb9\x87\xd6\xb7\xb1\xf2\xbc-Y\xb7\x105\x87m\x12~\x02BM\x98H\xb4\x92\x00\x1a\xe5T 0\xb0\xc0\x9d\xb7\xb2Boy)r\xb8V\x02\xfcG#'
        b'\x14\x8f\x99\xd2~J\xd0\xc5\x82O\xfc\x856L\xcd\xce\xc3\x00h\x16\xcd)\xeeZY\xab\xa2\xa3F{\xde\xdd<\x1d\xb21\xbb\xa0\xefY\xf5vL;\x10f\xbcj\x83^*{\xc7\x12\x08C\x01\x0bq\xeeH?}$'
        b'!\xbd\xccs\xef\x8eY\xd3\xb7J\x12\xd4\xb7\xc6\\\xeb\x15\xb6:\xa4R38\x9c:\x87\xf4w\xec\x95u\xaf\xb0(\x8d\x99\x1b\xe7\xb8w \x02\xa7\xc4\xf0\xcb\x13\xe8cC-\x1b\xedY\xc5\x96\\ \xcf9\xfba\x90\x0e'
        b'8\x996\x05n\xec\x97Z\'\xa2\xfd\xc5\x15\xab\x89\x1d\xcdq3\xf6M\x93Q\xd8S@\x1d|\xdc\x91\x87\x01\xed\xf0\x14\xdd\x0eN\to6\xa4}\x8f\'LW-K]\x80G\xf3g\xa2"\\\xee\xd6\x13\xb3K,#'
        b'\x04\xfc[\x85S\xe5\xd6\x7f\x97m2\xd7\xbf\xe3\xf6\x12\xd4\xd2\xda\xbd4_\x04gD\xb0 \xfc\xf3WpS#\x80\x08\x11\x9eK\xa2&\x12rV5\x07\x11\xf6\xdb\xe3G\x00m\x12J\xb4\\\x04\x88\x13R\xbb\x08\xcb?'
        b'(o\x95\x7f@\x81EG\x94\x98n\xca\x99\x810\x87\x8a\xf7%S\x7f\xa9w\xcdA\xc0-n\x1a\x9eX\x03\xb4\xe2nC\xc9\x04\xcd+>\x9eN7N\x07\x11\x15c\xab\x16\x86\xf9\xda4\xee\x10a\xbd\x85\xc7/(\xb0'
        b'\xe8\xdd\x04@@\xd0\xe74)\t\x9f~\x7f\x8d\x83\xb0\x1d\x9f\xa1\x89\xc8~\xbc\xdb]NOs\xc2\x8by8?{5U@\x9e<@\xa8\xae_\xcdp\x07/D`\xa5\x07P\xed^N\x8bE\xa1g\xcc\x82\xa8\x83\x12'
        b'\xe4#\x80\xadM\xcb\xe0\x12\x9dN\xbc\xed\x10\x88\x97\xf0\x9a[8\xd3s`\x8b*\x8f@\xfa\xff\x1bM\x93\xd6h\xe1\xa5B\xc1\xa1\x0fzcH\x16)"\xf4X\x1bY\x1e.\x06~\x92\xfe~\xae@s\x0c\xf5\xc7\xb4\xcf'
        b"q\x05\x98\xa5\x9bb^`\xcc\xbbw\x01n\x86\x01\xc66\xd0'\xc0\xd1\xe4\xab\xe7\xb5\xb7\t\xcb?z&\xa2z\x04e\xe1\x198J\x91[\x81w\x86\x9c}v\xd8\xb8Vo\x92\x11\x832G\xc4{\x07e\xee\xbb\xa2\xc0"
        b'\x94Wp@\xcf\xc7M\xa2G\x04a\x97\xe2*\x9b\xa8\x9f\x9e\xe6O\xb3\n\x0f\n\x87S\x0c%h/:\x9f\xc6rm\xde\xa7\x04B\xff\x18\x19\x03x5!\xc9.L\x1d \xf0\x16c{l\x94\xcd\xaa\xb1m|\xa6\x80'
        b'\xf9\x12}\xc2\xea\x96\x87\xc5|\xb0\x86\x8dm \x93\xbb\xc9\xd5\x85B\x05q.\xdaE\x9a\xdd)n|\xcfz8\x03\xafk\x0c\xcfo\x04\xe5\x07*Z\x9b\xa7\xfe\xffB\xeb`\x1c\x1a\xc2;\xa3M\xf8C\xfe\x87$\xf32'
        b'\x8a\x92GS\x18\xb7>P\x02\xe3\x19t\x9b\t\xa4K\x94\x8d}Ri\x9a\x01\x93\xb8\xf5Y\x8d\x0f\xb2\xc5e\xbd\x00<\xa2}O\xf8,uM7(4\xffU\xb5\x95\xbd)^\xa7\xe8\x0c<\x9f\xc9\xa9\x1e)G\xb2='
        b'P\xe7\xf5K\xe1\x8b{\x02\xd1\x0e:\xf3\xc2f\xf0\xd2\x93i}2\x0f\xe6\x83\x92\x1c\xe7P\xb5\xefr@u\x9dmT\xb0\x83\xbefV>f\xf9\xcb\x99Z\x8f\xa1p3\x947\x93\xc3\xf9\x1e\xe0}*\xda}\xbdk\xf0'
        b'\x92\xbd\xbb>\x01W*\xa2\x99&MsUP\xdb.\\F\xeb\xaeC\x12*-q\xe7l\xbe\xde\xd4\xcc\x00\xbe\xcd\xdaK3\x8c\x13\xc6\x97\xa0b\x14\xa0\x8b\x0b\xean\xa0=\x06\x1bn\xda\xe7\xd3\x1c\xf5]\n\xb2\xf3\x13'
        b"\x9cw\xf5s\x15OU\xee8$O\xfd'o@e\xbf\xa9\x89\xfc\xfe\xed\xd5\x966\xe3\x03\x12\x15\xd8\xa6\x1bpJe\xe8\xd8\x07\xcf\xb8O\xf7\xdf\xf1\xe7\x8e\xe7\xf2\xa9WS\xbc\xcf\x7f\x12\xe5`r\x18\xa8\xe9\x90\xeb\xb5"
        b'&\xae#\xaf\x1e\xb4\xb5\xb7\xd0\x01\xcd\xdcV\xf9s\x81\x1f\x80au\xf2\xd1\x85\xe3\xe5C\xe2g\xa3#i\xed\x96b*.\xfax\x0f0\xef\x91Z,\x8aU\x11\xb7\xd5\x85\xe6M\x9e\x98b\x87\x07\xc3f\xae\n@\xaa\xde'
        b'I<\xe5\x8dI\xe3\xbe\x1a\xc0]\x17\xcdb\x04\x1ej\xed@\x02\x06Z5\xe6\xe8\x0b\xf4N\x1e\x88\xa7\xea\xe7\xd9w\xe8k\xe7\xc3\xea[\x074\xa6\xfcc\xfe\xe3\xd1\x02i_`\xd6?\xcc\xdc5>\\\xdd\xc7\xb5\xde\x07'
        b'\xf0\x18\x03\x86{0i\x1f\xc4\xb5i;\xf9>\xb0O\t\x8df\xe9\xf8\x8c\xeeq7\xeb\xef,u\x0c\xf3\x9c\xff`I[\x85\x9e?\x9dk\xe4q\xc9\x8b\n6j\x0f\xc2\xe4\xe1\x0e\xc2\x94P\x9f\xad&t0\x85\xa9\x91'
        b'K\xfeCo\x82\xef\xae\x04\x932|\xcbN<"\xf8\xb9\xa6\xe2\xe6\xd9H\x89\xcc\xa2YX\xb7@|\xa6\xfc\xb4\xbfa\x8b\xd4\x97M\x8362E\xe4\xe6\x03\xc6\xfd$\xce\x9d\x0fn{\x14qAJ\x83\x1f\xd0\xf7\xdf\xe1'
        b'\xfbp\xf53a\xd4xs\xd5\xc0x\xed\xb6Kk\xd1@\xc1\xb7"]\x1d\xc6\x8fb\xd9\xf7\xf2\xbaQn\x1a\x1c\x17\x83bB\x9cR\xfb\xf6\x17^\xf0\x05\xe8\xe8\x85\x86\\\x14\x95`\x1e\xd7l\xba\xec\xc6\x1a\x87}K\xd9'
        b'\xd3\xef\xb2T\xf2\xf4\xde\x8c-\xc1\x1a\xb8ZK\xd1\xd7\xa8\x02?\xf5\x1d\x02\x86\xc3\x980\xec\xf8\xe0V\xc9hW\x12E\xc1\xf5\xb6A\x08(Omsd\x9d\x1c\xb2)\x93\x9a\xd1\xd9\xf1\xfagL\xec\xfd\xa4IW`e'
        b'\xb1\xcf]\xa4\xf0\xfc\xbf\x17\x1e\x84\xf1D{X\xda\x95N\xc4r\xca\xd28o\xc9%\x08\x1c\xd1y_\xaf\xb8\xc8\x07m3\xea\x1e\xed;\x17k\x19\x99\x9c&\xa5\xebxM\nW\x97F\x81xz \xd0\xf1qg\x17\x8b'
        b'\x91G<\x16\xbf\xc1-\xc8\xf4\x9au\x0b9E8o\x8e\x08\x1d\x14S\xa4\ng\x02|E\xd1\x10\xce\xca\xf4\xda\x90\xf5U\xb59\xb4g\xb2\x9aH\x82S\xaa\xd7\xc6\x14q\xffr\x96l\xd4\x94$\x13\x8a\xaaKf\x14O'
        b'1\x03v\xf1\xb6\xcd\x07\x9e\xd0I\x1f\x87CU\xd1\x99\x07\xc4\xd1\xf9s\xe6\r\xfd\x1a80\x8e\xac\xef\xfaOmjZm\xba$\x1c\xbae\x83\n\xd1m\x0e\xf1\x9a\x19>5\x0b\xbf\xc7,,M\xa6\xf4\xf5\x83\x1f\xf7\x0e'
        b'x\x0e"\xa4~\xa0@A\x81.\x0f5\x9c\xec\xd9y\thG\xd1\xc2\x1b\xb0\x9f\x1c<\xaa\x14<b\x8f\x1e\xe5\xf9V\x90\x87NK\xeaq\xb7r\x84\xe2\x91?\xcd#|\x7fq\x96\xe9\t8C\xa8\x04\xed\x1e; \xcc'
        b'\xe9=FZ\xe6\xcc\xed\x98\xc6u\xe3\xa4\x92i\x9e\xcf\x7f\x1d{F$\xfdF?\xc9\xd7di"7\xc4\xc11\x94!\x08-,\xda.\xd5a\xd4\xf6G\x95\n\x9c\xa0\x15\xb6\xfb3L\xee\x9eb{%\xb5`_o\x99'
        b"\xbf\x19\x0e\x1fb\x18@\x00\xba\xfc\x9f\xdbB\x03\t'\xaf\x14\x0b\x00\xc4\x1by\xe2\x88\xefv\xccz\xe8\x85\xd4e\xa5\xab\xbd05]w\xa9\x1c\xdf\xe5\xf8\xbd\x07\x0er\xb76\x84uj\x1e\xb0Qr\xdd+\xd3\xc1\x95\xa5"
        b'4H\x7f9pn\xb1\xc3\x08\rkP%\xfc\x8f\xa0\x93n\xdco\x9ak]\x9dDE\x17ZB\xda\x8d\xf0W0)`\xb5h\x8a\xc0$\x9853\xaeU\xa2G\xa3H#\xc6\xe9ea\xb31\x10_\x85\xca\x13\xa8\x19'
        b'j\xdb\xc26J\xa3a\x98\xe3\xb4\xfb^\x7fR\xccx\xe9\x83^\xcc\xbe[\x1b\xdf\x06\xbf\xb0\nla\xfd\xb2[4\xdcy\xc7\xba\x18f\x80\x13N\xd3\x95\x8a\x04VC+M<\x94I\xd9v\xd6\x19\x14J\x16\xa8\x82\x99'
        b'\x93\xca\xda\xd8\xbai#\x95\xe0\x9f)\x03\xac\tk\xca\xe3\xa3qK\x06\xfc\xab\xa1\xfd;\xacT\x8c\x94\xb6\x8d?5I#\xf2\x88\xd028\xc4\x0b\xcb\xc7\xf4$\r\xa7\xa9\x0c5\xfb\x94\x16\xef\xc5z\xd16\xbb\x03\x93\x8b'
        b'R\xe7\xa4\xa83\xd8\xf4\xa1\xdb\x0e\xd5\xa9\xc5\xdd\xc7\xd5\x02I\xab\x06p\x17xA\xfe 6T\x1b/H\xd2\xd0c\x0eX_\x90N\x7f\x93\x1dm\x01\xb3\xeb\x11\x0bP\x02\xd8\x9a\x97\xfc\x80o18\xf2cPP\xeb\x98'
        b'k\x93J\xfe>~\xea\x81\x84r\xac\xdbI\xa2xd\xd1D\x994\xb3\n+\xd2\xdf-3\xf4\x7f\xf8M\xf3\xe6&\x9cCYDN\xea\xedT\xf9\xd0\n\\\xa05\xfa/n%#c\x95\xc2\x9et\xc0C%\x0b7b'
        b'=J-\xea\xd4\xdfJ\xb4q\xb4\xb2\xbcD\xd2f$x\x82y\x02j{\x16\xd51\x17\x1e\xdf\x11+\xd6\x828\xdc\xd3\xde\xc5\xa6\x88\xc2|+v\xfcP\xb9\x93\x94y~\xf8\xa4[\xc22\xae6\x95\x9f\xbe\xda\xc5-S'
        b"\xdc\x99sX\x83p\x0c}\x07\xf3\xa9b\x8b\xc2{0\xec\xb9i8\x1d=\x10\x82\xac\xdf\xe3a\xbb\x84\x90\xa1\xfb\x9fi\xb3\x16<\xde\xe5\xa8J-\x9f\x0b\xc9F\x18\xf5'\x83~\xc6g\xd3'\xf7\x05\xca\x0e\x9b\x12\xb9V"
        b'\x0b^\xac\x07\x04f\x03\x9e\xd9\xccSs\x8ay\xd0]\x0e\x10\x0fH\xa5@\xae\x80\x1b^\xa6\xd8O\x8c"\xa0\xe9\xe4\x17,:\xc2\xef 8)\x1e\x15v\x8b\x17\xb4\xe0\xb9\xaf[\xceXX=\xee\xda;\xff\x92\x00\x1b\xe8'
        b'\xc9\xf3C=@\\>\xd7\xd8\xed\xe2Jq\xe0\x97\x1f\xc9\xfa\x9f\xbc\xe2\x87\xabE\xe2\xfc~~F\xfb\xf0\xbe\x9c\x9d\x07a\x83-\xcb\x88\xc6\xa0\xa5\xcc;>\xf2B\xb0^\x07\x06\x9f\x972\xa0b\xd8\xda\x1d7\x1e\x1b9'
        b'\xc38\xf3n{\xf8,\xcb\xe6\x85\x04\xdd\x9dI\xa3\xe7r]\xfap\xd0\xf9\x02\xf7\x9c\x02\x10\x08\xa9#\xd4\xa12\x18C\xae\xa2A\xa1g&\xce\x1a&\xbd\xb1\x06\xaf\x90D[\xadE\x04R\xf9\xf3\xbd/\xaebY\x90\xb0'
        b'\x86\x18j{O\x1f\x9cOL\x1c]X\xcf\xc4\x90K\xb3D6\x08\xedN^%\x0f\xe7\xaf5\xdb\x16\x00\xaa\xff\xf3R5\x9e\xb6\xe5\x9a\xb6\xa9\x9c\x16\x0f\xfa\xef\xa2\xbb\xca\x00\xdbD.\x93\x96\xca\x88\xfb)\xc3\x90t\xa5'
        b'Yq?B\xc7P\x83\xd3K2d\x12\xb5\xe6\xcb\x11\x9e\x0f\x1d\xd6Yw\xc5%\xc9b,\x81m\x98\x89l\xab=\x98\xc2"\xddm\x0f\xea\xd0\x1d\xe5\xb0\x1d\x06B!r\xe8Zv\x83\xa2\xfb\xf4*[\xea\x87=\x87{'
        b"XiS\xf8\xb0\x08\xae!\x051\xd5\xbd/;\xe7\xc8}\x18\x94\x8d\xcapl]\x15?\xb7ycul\xb8,\xa6}\xdd\xc9\xb2\xbc\x9e\xf5'l\x0f\xbe;\xe2\x18\x17\xea\xa9\x0f\xe3\x01?\x8dr,\x1ag||\xc2\x89"
        b'i$\x8e\r\xd3\xf6\x18\xb5!*\x8fF-\xbb\xe9\x9e>\x8d!\x8b\x1bM\x0f\x05-+hd>s\xb1\x81#\xb2Z\xdfT\xdf\\|\xe8{+\xa5\xc1\x1a\xc1\x93jB\x877\xc6\xfd\xa3\xb2T\x02\xeb\n\xa5\x05C+'
        b',v+\x9a\x97\xb8\x1di\x99# DG\xb2\x91\xeeg?\xdc?\x18\xd5\x15\xc4\x8d\x9b\x8bN\x87\x8b\xb1\xec\x8c\xa5\xc9m\x14\xd8\x05p\x16\xcaz&+\x9b\x18\x9fU}\xfb\x9b\xa3J\x16\x11\xa9\xf3)\x05C(|\x92'
        b'\x80f\xa4\x94n\x92)\x1a\xfd\xdb\t\x94\\\xa3x\xc5SM\x1bi.\xc0\xbdw7\xb89\xff\xbfbor\\\xe0\x84\x84\xa6\x12`\xfb\xfc\x9c\x81\xb7o\xb3KP7\xf3;\x8d\x02C\xebFM\xa0\xa5?C\x12"y'
        b'\xd6\xc6\xbc\x8d\xeb\xbc\xac5>V\x0b\xf9\xa20[\xb1\xa2G:\x87-\x19}N\x06_\x9f\xabm1o\xd2l8x\xe3Vmp\t\xac\xfc\x01\x15\x81z\xe9\x8a\xb0>\xa9\xef\xc8\xf5N\xc5e\xa4\x9e\x93o\x88\xb3>'
        b']\xb9)r\x1d\xa0\xbfI\xceY\xa9g\x1a\x9b\xa8m"\xd2\xe4\x9d\xea\xa5\xbd\xb8\xef\xeb\xaf>\xb1\xb3+;\xc1\x00\x1edu\xb4-\xd0\x0b\x16$HG\xe0\xb8\xe8\x9a\x8bR\xc9\x1e\xea7,a\x9eyy\x16\xaan\xde'
        b"6\x9e\xcd\x11\x94i\xb8A\xc6p\xc7\xa2\x9e\xdf7\xad\x1b\x05\xe0\x0c\x8a\xcb\x0e\x9d/\xcee\x86R|\xc5E\xda$L\x17\xb9\xe5\xb3\xc6\x1a\x0b{'\xdf\xaf1\xc4)\xe92^\xa5\xa9\xa2\xc7Z\xce\x83'\xdf92\\"
        b'\x07\x9b6*i1j\x9f\x94\xb2\xb47)\xb0\xbb/\xc7\xe0+B6u\xad\xa5\xc5\x87o\xc3\x17\x8f\xb9\x81\xb5D\x8c^9\xba\xdf0\x92\xf4\x12\x14#\xeb\x80\x19Nr\xd7\r\xf3Q9\x8e.\xd4\x8cz\xffLB\xf2'
        b'\x1b\x04\x99\x8e\xbf\xf5\xfb\xbb\xe86\x97\x99\x9f\xa6\x8d\xda\x07\xe4\xc2Y\x92\xf2\xecb\x9a\xfb\xd82\xd9\xa7\xe4\xba\x9bf\xab\xec\x02\xe9\xcb9^\xe5\x0e\xe0\xd1\xd67\xdfG\xc0\x9ay\x91\xcf\xf63#iU\xf2\xceo*\xab'
        b"\xc1\x15\x17vi3#xB^Z\xdd\xd4\xd8!\xc1\xe7o2\xf1\xc9\xd8\xda\xa1\xe1\x9d\x08$\xa015\x94\xd1$'\x82\x1f\xf8Wh\xd59\xfa\xea\xb3Z\xca\xa2\xcd=\x89\xc3\xdc\xd2\x92P\xbc}\xb1\x05\xf0\x1f9a"
        b"[\xf1\xa2ar/(E\x889!\x1f<o\rn5)\x06n\xc4\x91<o\xb0\xfb\x1f\x02'\xf5WH\xd5\xf1\x06i\x92\xc4\x84\x86\x1b\xda=\xa9\xc1ND-\xf7\xee\xa9\x15\xbaI\xe1\xe2\x83\xfceu\xaa\xe4\xf9\x98"
        b"\x04\x8d\xd1\x7f\xb8S{j,\xbb\xab\xd4\xe9\x0c\xe7\xce\xbb\x17\xd8\x0f\x90\xb0c~\xea\xcep|\x91\xe5\xb6\x14\x104J\xea\x90\t\xd3_\xe6\xad8\xba'\xea\x00\xe4QJ\xa2\x8bOZ\x1c\xdezW\x92\xacwT\xc9\x89"
        b'\x0c\xee\x07\x87\x19\x00\xfa\x92\x8ba\x8e1\t\xd7\xc1\xfd\x9c\xfa\xc5\x0c\xd2v\x9c\xba\xfd\xe3\x1d\x10/!\xa2\xb2QX\xb6\x9e \x87Jo\n\xf8\xe4\xbf}v\x19a#^Z\x14M\xd6\x07\xc3(\xea\x1bu.\xb8\x19\xc7'
        b'\x97<\xd3\xee\xefC\x8a[=\x0c\x9d\x03\xb2+t-\xff\xfd\x05Z(\x9b\xff\x1e\xe2b\x89\xbd\x9f|\x1c\x086\xaf[\xce`\xe5Z\xaf\x0e\xdb\xdf:\x1d\xf9\x0ejJ\x87\xce\x86\xbb\xbf\xbb\x0c8\xd7\xe3\x97\xd5\xbe\x91\x9a'
        b"od\x1de\x85\x18A\xdf\x98}\\\xc1\x1d\x93\n\xebl\xdd$|\xc7\xaeI\x1f%3'\xb2\x8e]D\xc9\xe7\xe7\xd9Bg\x00r\x8c\xf2S*#+\x9e\xf1\x957/8^\xad\xe7\xe0[\xd4<\x9e/O\r\x8c\xd8"
        b"v\x91\x1cycL\xf9G\x01[Q\x11$<w\xec'Uk\x07\xb7\x11\x1d\xdb\xf0\xb4\x92z\xdcr\x9b;8\x8aN\xad\xe9\xc8(0\xb6(\xa2\x0fP\xbf\xdc\xd51\xdb\xdc\xe4*T\x124L\x1e\xe1D\\\x7f \x0f"
        b'\x89\x91;g\x07\xaa\xe1\xf7\xea\x11`\xa1\xf7\x1br\xf2N\x01\x96<\xc9\xb5J?u\xc9\x9c\x05\xcc\x12V\xb4y\x84\x7f\x15\x1d\x98~.\xd8\x8a\xde &\xe6\x1b?\xf9\x1b\xbe\xbb(\x8a{\x12\x1d\x115\xfb\x90V\xa2\x1a'
        b'x, E8@\x18,\xa7I\x85\x01\xa8\x03\xd9E\x13\xe3\xa7b\x85\xb1\xf6|\x910,\x8a\x13JB\xbfq-t}\x8eZ\n\x17u/\xa90T\x89\xf4\xf0\x97]\xb3G\xf3\x1aB:@m\x9e>G\x84\x8e\xc8'
        b'\xea%\xa3i1\xe4N5\xd1\x07\xbf\x90\xf4\xf2K\x99\xd9\xaa,\x12\xe0\xe3\x04\xc6$\x86\xae\xd1]h!i\xa6\xf7UX{\xe6\t\xf1\x8b\r\xfb9\x04p\xcc\xb0=\xc5\xa1t]\xffB\x9f@\x87e\xe1qX\xf4\xe9'
        b'L\x1a\xe0\xaf\xb2\x12~\x03X\xdf\xdd\x0fR\xc1\xb38F\x1c\xa0]\xe3\xef\x9f.b\xd1+\x8b\x92\x18\xe8|=\xe2J$|\xc2A\x1d4\xecC\x02\xb4hlWfhU^^\xa4\x9f\x81S\xb6\x08\x10/\xb25?'
        b"\xad\xc1\x03\x95d\x9dn\x859k\xe7]\xec\xa9\xf3\xdf\x05\xa8\t\xceq$\xe0 \xb4\x01i\x9f\x03^\x8b\xe3)y1\x8d\xfa\xc2\xdb\xeeV\x1e\x85du\xd7\x10c's\xe7\xfeQ~\xb7-\x0c\xeb\xa6\x95\xc45\x83\x06"
        b'!{\xfbG\xd2\xbe\xcd\xa1\xb8\xe0MI\xb93\xce\xdb\xe7R\xdeH^\xdaW\x13\x1a\xbeK\xd5\x16\xd8Z\x89\x9d\xcf\x11[w\xff\\\x0f\xb3\xe7\xd9\x94\xe6\x13^\xf8\x102\xcb\xd7\xab\xb8\x114\x16\x08\xc0\xf1\xc9\xc1=x'
        b'\xc7\xf1\x1b\x9c&@\n-\x92A\xab\r\xc1\x83\x0bB\xcc\xa9F\x95{\xc0o\xe2\x0f\x04\xdc{\n\xe5\xe5\x9f\x83\xc3\x171.\xeb\xc9\xb1\xfd#\x97\x85\x08\x92t\x9f\x91)\x9a\x99\xed\xae\xbbK-E#\x06\x90\xd6\xafJ'
        b"\xec\xda4\x19\xe0\xc3\xf6\xf8{\x8dq\xb8W'pUh\xf8\xbal\xa4'f=\x1dOx\x05\x1bS\xb5o\x92\xc4\x06\xa3\xf4\xa6\x08\x86\x7fu7\x1b\xbe\x82\xc8r\xdb\xfb\xf9\x06Fz\xe2D\x9dC\xa8n\x14\xe6\xeeY"
        b"\x82\n\xcb\xb7\xf4j\xe6\xfc&\x1cvv\xd3nT;\xc5\xadD-\x8bq\x04\xf6\xc7\x9e*\xebkX\xa6\xe6\x8c\xdd\xbfdM\xd6F\x8a\x12'.\xa6\x98\xd3\xcd\x00.6\x9f8\x81\x82\x14g3\x80$\x11\xca-\xc4\xdb"
        b'1kT\x8fV\xf2=\x15\x06\x07\x0e\xf1R\xcb\xb79e\x84\xb2\x98b\xa1\x08h\x96=C\xf45ol]\xf3\xa5\xbdBK\xba\xf30s\xde\x1a\xbc\x03\x83\x99\xe6?/.\xc6\xbf\x9b\x12m\xa7\xeeHW+d\x86\xd3'
        b'd\xfa\xaa\xa4\xa1\x81}\xf2\x89|0\xc5!\xc3\xe3\xa4\xbf\xfe\x1d\x13\xe1\xb9\xd3\x10a\xbd\xff\xd7j0\xbb\x14\x1d\x81\x02\xfb\xcb\x92\x81Uhdi\xafi\x1e\x98\xf4\xf2\x99=\xe3\x05&m\xec\xd6>\x1c\x9b\xfc\x84\xffE'
        b'\xe8]0\x14\x0b/\xc9\x89\xb5\xcd\xd6*\x00Dw\x85\x91~\x9c4\xfdA\xc0\xfc4pH\xb5\xbcLZ\x86Nq\xd4\x8ar\xb6\x05\xcb\rEu??\x1a\xf7vJ|\xf9a\x8av\x98Y\xff\xf8\x0b\x0e\x18&it'
        b'\xe6(\xccJ\xee_\x8b\x94\x11q/b\x93=\t\xe8\\\x08\xe8\x05E\xff=?\xcf1\r\xe7\x95:%\xca\x00\xce\x87\xea\xed\x85\xde\x80g\x1a.yA\xcf\xabG\x7f\xf1h\x08\xba\xd171\xf4\x91\x99\x87&I\x96\xab'
        b'~\xff_\x13?c\x01\xa0\xf2\x0e4:F\x06\x12X\x98\x83\x85M*\xd8\x9c\x07i=M1V\xae(\x96T+a~+\x98\x9e\x97\x82\xf4!F\xe0\xf8\xbc\x1b\xbeoE\xc3\x86=\x97\xcc\xc5XF0K\xadqT'
        b'\x86p\xd5\x1c\xe3\xc9\x1f\xfd\xd2p\x05.\xbf\xd5\x03\x15Q-Z\x8b\xeeD\x1e\xa6Uo#U`\xcf\x08Ox\x00W \xa9\xbc/\xb1\xe1[\xc3t^\xe8F}\x96\xc6\xb3\x7f\x88\x0b\x88\x85\xa0\xca\xb8(\xcft\xc4\x1f'
        b'zGs\xfc\x05*\xecB)\\\x8ad7\xcc\xb4\xc6\xd8\x8ewxga\x99\x99\xb2\x9f\x86#\xbd\xd5\xba\xbe\x077\x83:\x08?9$\xad\xe6\xba\xabh\x18\x8bFC\x95\xe6\x99.\x91\xd98\x98\xb7s\x82\xf8\xc3\xa8\x02'
        b'O%y\xee\xdc\xec1\xc1\xe8\x0c\xd6\xecU$\x99hE\xefcv\xc16\xab@\xa5W!\xda\x82^\xc5HG$XO\x03\x16yT\x02P$\x08\x1f\xbf\xfd53?\x83n"\xf5\xec\xe1\xc1\xcc\xa1\xdb\x08\x11$}'
        b'=\xd1\xec\xa7?\xd2\x9f\x0c1]F@C.(\xa3\xc8\x1b_\xb7\x8e\xc6_\x88\xdc`2h\x88N\xf6\xb4r\xa2~<\xf0.\xcd\xa1G*\xfd97\xb9\xac\x1b\xee\t\xd5\x01\x18\x0e\xa8\xf5n$nCt\xfb\x06>'
        b'?\xc9D\xd4A\x9b\x1d\xf9\xdf\xf8\xb0_8\xb2)/2]\xef3:?\xc1\xe2\xb36\xac\x1c:(\x1b\xd7Qdwj\x01\xcc\xdb\x19\x06\xc3\xe6\xac\x08\x8ffj\xf0\xe6\x06C\x13\x91d\xb1\x80(\x8f\xc3\x14-\xd9\xa5'
        b'\xd3e\x0c\x01G\xc9\xc9\x18\xf7\xe3\x8f\xc19\x0f\x9d[V:p4W&\xb0\x077\xacw0|\x98U\xfb>\x0f\xc3\x04q\xad!-\xee\x0f\xa3\x91b>\xbfS9\x8a\x83A\xaeN\x1b\x93hwV\x18\xf3Mx\xc7'
        b'\xab\x97\x13J\xcd\x06\x85\xf1|\xe9\x1d\xcb~\x9d\xc1\x0f\xfb[\x00\x86.\xc8\xb6O\xb3{k3\x9e\xc0E\x91#\x13\xe0\x93\x82\xbc\x84]\x11\x82\xday\xd2\xbb<\xe4\xf6uU\x15:\xa8\xcd\xb4\xa4_i\x9cz\xb2N\xc8'
        b'7}\xf7.)\x9e\xa0\xc2,}\x90Y\xfe\x84\xeb\x1e\xc8!u:\x84U\xe2\x14\x91\x96i\xe4\x01\x80\xc6u\xf7[}\xd73\xd4\xf0d}\x81>,\x94l\xa3\xf9\x9dU>\xa9lN|\xe8\x85\xf0\x82\x8c\xb8\xb9\xf2r'
        b'\xf1\x9f2jB\xc0y\xcf+\x1b09\x03"\x1a*x\xae%\x08\x1c%\x96Q1\xeb@\xb0(_\xec\x84\x92\x8a\xaf\\\xf5jPL\x97\xff\xc8\x01^\xdf\xfeFf\xbb\x8d\xb3\xd9\x0c\xf3\xe1\t\xf9:\xa0\x89\x8e\x93\x9c'
        b"Q\xdf\xa6\xceR\xd1\x9ei&\xf6t\rz\x01BW=\xc8:\x13\xcc\xcd`\xaa3\x83\xb4nw_\x07b`Re\xd7j\x8e\x81\xe0CI\x0e\xfa\xc0GK\xf7#e\x93\r6\x80'8_#\xb5S\x19\x90\xb2%"
        b'\xe5t\x82\x0f\x8a\x98a\xf2z\xb4\xd0\xcc\xd0\xdd\x88\xde\x7fL\x8f\xa7A\xed1\xaa"\x88}i\x995\xbc\x82\x0b\x81/\xe8\xf4\xa9@\xe5\x14\x03n]\xb8N[%w\x98\x9e\xe7 \xa8\xe8\xa9\xe9\x98\xa55\xc9i\xd4\xfe'
        b"\x1c\xed\xc5\xb2\xf2\xbe\tA\x9c\xcf+\x18\xdb\xf3\xa9\x89\xf0\xdfAY\xdab{\xdc\x1e\x92\xb4\r\xb6\xa4$z:\x8e\x92\xfe\x96\xb9\xefs\xb4\t\xb0\x05#\xc3\xe4\x9e\x16#\x1d\xa8\x0b2\xda\x0e'x\x07\xc5m\xf0\xc3\n"
        b'$55\x19\xfbS*x\xb5\xaeq\xd4\xe5\x91\xdbf\xb38\xe6\n\xfe\x7f\x1a\xb8\xf2-p4\xad\xa6*dI\x888\xff3NUTe\x91\x13\xa1\x9bfEM \xbf\x89\n\xa6{\xaf\xb4s\xa8\xd6\xb5\xeb\x14\x8d\xd3'
        b'\xff\x80D\xf4S ,\x1e\x18c\x14\xd2\xbe}\xdc\xc1\x1e\xd5b-o\x19\xb6\x0c\x01io\xb1\x91RC3\xd6\xfd\xa6\xf6\x9f\\*\x8d\x97w\x00V\x12`S\xde\xa5S\xe4\xc6\xb5{\x1c\xec2\xc6\xca\xf5\xf0Mvr'
        b'\xce-8t\xef\x1e\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r'
        b'\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x15<frozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x06\x00\x00\x00\n\x00\x0e\x01\x12\x01'
    ))
