
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s*\x00\x00\x00z\x04e\x00\x01\x00W\x00n\x07\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01e\x00e\x02e\x03d\x01d\x02'
        b'\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xd2.\x00\x00PYARMOR\x00\x00\x03\n\x00o\r\r\n\t4\xe0\x02\x00'
        b'\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x92.\x00\x00\x00\x00\x00\x00\xff\xd2.\xd8\xa6\xb0\xdc\xf2\xeb.\x18\xde\xe9\xb6\xb0-\x00\x00\x00\x00\x00\x00\x00\x00\x19\xfc\xe5\xc6c\x91\x87O\xef\x11\x0ck\x8c\xb7\x9e\xc5ke\x0b:\x1a'
        b"~\x00c\xf9'\xd5\x177:\xcemO\xa0rx\x8aZ\xf5\xe6\xac\x82\xe4\x9c\r\x95\xb1\xde\xe8jc\x13\x07K\x02`\xf7\x02\xb3\xc9b\xe3\xf4\x00HWQ_\t\xf4\x8c\xe5\xc0\xf4\xfe4(\xac\x95\x0eX\xbb\xe5\xec\xcb"
        b'V)\xf5\xcf\xb8/}\xb2\x9d\xe7%\xa6&J\x9c\x05\xcb\xd7\x98G\x04\xd3}\x08\rFC\xbe\xdb\xa4|\xcc\xb5\x91\x11\xe6\x1c\x0e7\xcf5>\xe1m\xc9\x96}\\\x94\t\x02\x8e\xb3\xcc\xe1\x8dl\xa5BL\x90s\x9e4'
        b'\xe3\xbf%R\xcb\x92\xd2zg\x87\xd5\xee\x8b\x18\xce\xa9ak\x11\xc6\xa4\x1cu\x86m\x90\x94\xcf}.\x13\xa14\xfd\xec\xd3n\x811*\xf6^\x1b\xf7\xc4\x7f\x8c\x84\x01R`\x93k\x07\xbe\xd2w\xca\xb1ohA\xa1:'
        b'ph\x88|\xae\x8b\xb1NB6\xc4g\xe1\x19+\xb9\x105\xf8\xd2\xf8\xd8\xaeFT\x8ef\xbc}\x99e*\xd8584O\xe6G>\x00)o\x95\xc69>;\xd4\xc66%\xeb\x86\x17\x82\x8f\x93~\xa9\x8b\xb6\t\x05'
        b'\x8e\xdbKV\xfet\xe6\x98\x12\xda\xc30\xf7\xf1\xe8\x08R\\\x149mQ\xfb\x17E\xd7\x06\xa7\xa9\x0f\xf4\xc5\x07S\x80\x16\xda\xff\xc2\x17Ps\x96\xef\x90\xb4\xb5\xa61\xba\xe9\x94\xb7\xa4{\x82\xcaY\xf3\x82\xf3TL\xbf'
        b"\xb0\x84\x80\x18\x81\x01\x15\xfaU\xe2S\xac\xfb\x7f\xf0Vh~a'^~\xb5\xc8^\x8f\xd2\xa6 \xdbEO\xaa\xbe\xc3\xa1\x11\xf6\x9d\xa5\x1e\xd5w\xcc\x13a\x0e\xed\xc4(J\x9f\xeco#\xaa*s\xa3\xc6a\x0f\xb4F"
        b'r\xcbr\xd2j\x88\x85\x18|\xdbap\xd0jDZ">\xa4\xbaUz\xd95\xc2\x8b\xda\xd2z\x8a&\xa6\xb1}3\xdd\xe9\x0fj!U\xb7\xe8C\x87\x08ty\xee\xd1\xc7\xdb\xfbn\xb0\x15\x7f\xddEz\xf5\xebQ^'
        b'\xeat%\x9e\xa1\x9b\x0f:\xa3@g\x10\xf9\x86]n\x9d\xe1\xd6\xef\xb9\x12\xdcy\xbd\xbd{\xb04\x7ff\xb0\x0f\xc7e\x02\xe7\xd9\xe5\x89\x03\x0f\x12%\xd6\xa7\xbbR\x96nZ}$r\xf39&Ehy\xc0jaU'
        b'\x89\x8df4\x1c\x043E\x06\x13\xec\xba\x7fUV\xb2\xea\x10\xc6iJz{\xab\xd7I*\x8c\xb4\xd0-\x9cGy\x0eI\x0f\xaf\xa7Y\t\xc6b^2.\xdf\xce\x90\xf8\xd9x\xb5\xa7\xcf9%G\xfd\x06\xcc\x84"\xb7'
        b'0+\x88\xdc\xa1\xb9V\x8d5)\x91\xd7\x91p:\xf1\xdc"\xce\xdd\x00%\x91\x17=Y\xd7m\xea\xb6\'J\xac/\xda\x9a\xc3`\x00(r\xd8\x80\xb2\xa9\xfd\xc4z\xa9\xf3\x83N\x7f\xa9gp$\x93\xc9e\x1c>\xfa\xd3'
        b"N\xb4?8\xadO\xf3\x9e\x809\xdd\xd4\x96\xf1\x03\t#\xd4CB\xf0\x02'<\xf5\x8c\xc9e\x93\r\x13\xfa\x12\n\x84.\xc6\x8a\xf5\xdb\x81r\xbb\x92!\xbfbx\x86D\x9b\xa8\xdd:uGM>\xeaV\x04m\x8a\xed"
        b"\xf5\x98\x15\xad\xc7\xd8L\xf9\xfb\xe2X\xdd\xe1'\xb9\x94\xb5\x81\xa1\x92\xf5\xba\x1a\xc9\xb7\x85\x82fv\xeb\xc5,\xe1\x9a\xd7u\xa7f\x01\x1er\xfe\x1b\xc0\x96r\xb6\xc1\xfap\xf5s!lQ\x16\xe8\xa5\xc3\xce\x80\x86\xd45"
        b'\x05\x00\x80\x97R\x0fd*\x0f\xbd\xcf\xcb[\xb2F\x82[\x80\x141}\xd9\xe9]\x88\x93+\x82\x88\xdf \xaf&\x89\x82\x10-\x00\x80\x89\xe6uA}E\xfd{\xc1@\x872\xb1q\xa4Q\xeb\n\x9d\xc8L\xb6/\xfb\xcd'
        b'\x85\x1eT\xe8\xb2\xbb\x15\x86\x92,\x03-YVj\x86\xef(\xfc\x12\xa8\xe08P\x9d\xf2\x02\x1b/\x06\xf26r(\xbaN\xf5L:Mnf\xb6\xa3\xf4\x1d\xd9\xe7S@.T?5*A-\x86\x91\x7f7\xad=\xd6'
        b'\xb7\x15\xb3\xf0\x06\xb8\x05\x18M\x9b`\xf9:\x9a\xb7\xc1\xeb\x0e\x88\xfb\x81D\xdf@\xde\x1aa\xc2\x19\xba\x7fsFp\xc7$\xa1y\x84\xd5N\xbe\xee\xe4\x1e\xf2\xd5\x0b\xc7\x14\xefx\xd2&\x92\xafm=\x00\x1fk \x10\x1e'
        b'\xe2\xae\x03\xe6b4n\xf0\xf9"\xd1!3\x84\xb3c\xddn\xe9\xceZa\x93\x02\x95.\x9c\xd0\xd6/\x81\x10\xb9UUPv^b\xac\x9b\xa2\x8b\xb5y\xde\x8b\xeco\xd3.\xdf\x8a\xe3\x9d\xff\xf8\x06lIV\x8f\xd2\xa4'
        b'\xcb\x00\x99\xf1\x83\xcdb\xef\x87\xe5\xd4\xf0\x1b\x19\xed\x9d\xf7r\xa1{I\xba.\x9b\xaf\x7f\x14\xa6uN\xc4\xcf\xf3\xe7C\x87\x04\xd1?\x80\xf73\x9e\x06\xdd-%\x85\xb6\x0e-\xdc:;\xd8,\x02\xe0\xcb\xa8\x80Z)B'
        b'\xa6^\xacW\xf4\x1f\xc3\xe9\\\xfcypL\xb4\x938v\xf3\x9f\x80\xdd\x8d\x03\xd7GoCh\xa2\x97\xdb\x9f\xc1\xc3\x0c\x8a]ga\xb7N\xca\xb0,x\x10\x98{\x0f\xfcnDZ gbVU{]\x8b\xf6K\xd9'
        b'Z\xdcHD\xb1.\xf9\xe2{DaN\xc9\xa6\xad\x17\x92\x14I\x8d\xb2M\xbe<\xee\x10\x18\xf6\xa6\xbe\x9e\xb2\x1b\xacod\x80\x9c\xef\xd9\xd9bp\x1co\x89e5\xea\xe1\x9c\xc5Xn+\xa5\xdb\x0f\x87\xeb\x95:\r/'
        b'\xb3PV\xaeJ\xa0\xde~\x91\x9707\x99\xd2\xd4\xab\xe0\xbdG\x8a\x16\xce\x93d\xf8\xb74t\x0b\x174S"be\x8b{\x86\xe9\xe7\x1d\xc6\x08IC\xd8\x96X\xdb\xca\xfc\xc5\xe0\xf7\xc2\xbe*\xf2\xf3i\x93PF\x99'
        b"\xa1\x14\xa2K\x8a\xb0<t\xca\xce\xfdXg\x8c\x85\x06\x93\x9a\xeb\xbd?2\x14\x9c\xa39\xbf\xe4iHaR\x0c\xd9\x9d\x05\x9cy\x89Yw\x1c\xea7Li\xc8\xa2r\xdd'\xd8\x8f\x1e\x06\t\x9dm\xe9\xf7h\x99`\xab"
        b'\xcbs\x00\xbdU\xbb\xe8!\x0bi\xf7\x1eP$W\xb9\xc1\xf4\xde\x1b\x81!\xa2\xc5\xa4I\xbc\xecr;\xee\xb8\xfe\x86\xfcn\xe7\xed\xd3\x1b@\xf7\x84\x9a\xd1\xf5\xc0\xc8YF\x88\xc9\xc2\xe2\x15j\xd2\xe3\x99M\x13\xc2\x1c\xc7'
        b'\xde\xbe>\xb4\x17\xe3l) |K\x16\xbc\xd8\xe2\xe9\x0c\xae7\xa0\x89\xffk\xed\x88\x97\rB\x87\xc3\xec\xac#\xd1x\xc3\x1c\xae\x93\xb1\x8d~\x04P\xc9\xd9\xa7W\xe8\xb5\xff\x12\x03\xc9-/v\xb2\x0fZ\x0e\x10z\xa9'
        b'\x12R\nv\xa6l\xa5v\xb8\xd1.W\xf9\xfd{\xd0Qu\xaf[\xb92\x89\x13\xfeJ9(\x82o&\xdep(\x83\xa4a\xf3\xe94\xda\x993T\xfd^;\xa7v a\x96c*\x9df<\xa2BR\x11\x81\xe2\x8e'
        b'y\xa8E\xd3\xb3\n\xaa\xdd\xab\x0cQ\xf8\x0e\x19[\x10F\xf8\xc6\x8e\xee"\x95$X\xee:\x8f\xcdR\x8fh=\xa0\x19\x96\xfc\x10g\x0f\x00\xab\xe9\x9f\xa2\x9d@N\xdf\xe26v\x0eL>\xf2\xaaU\xbd\x83\xff\x8ar\xf7'
        b'\x10:\xf4M\xabJ.o!>\xdc\xc7\x81V\x8bJ,Cn\xe2`\xa2\x96\xe9aaG\x9b\xe9\x16\xc6\xaa\x83\x95jQ\xb8\xf2\r\x1e$\x18s\xdd\xb3 \tu\x91\xe0\xf8\xf7\xc3\xd7\x88\xd6k\xa8\xb6<.1k\x82'
        b'\x92\x90\xa3F\xb4\xfaf\xd8\x06tqqo;/\xf48r\x9e\x9b\x17\xd4J\xdc\x8coUO\xc2\xde\xc8L\x0f8\xb8\x04r\x16\xe9\xd7Qb\xbc\xb5\xe2T\xff\x9f\x1a:\xbdz\x91r\x04\x86p\x9aK\x96\xd8\xd2\xda\x1c'
        b'\xe3\\I\xaa\xa3#\xfd4\x80S`\x8f\x94\x97\x01mi\xe3N|8}%Y\x9e\xdf\xda\xb9K\xb7HE\xa4jX\xfb\xb1{O&\xda\x0c\xa6\xd44\xc9\x917P G\n\xd2\xfa)?o@\x85-\x10\x9ehg'
        b'\x05U\xd2\xc3l\xb1\xe7\xc5\x9b\x96\xa0\x16K\xb7\xb5"\xa3!&V\n9r1\x0f\x10\x98\xf3\x1e\x9c\x03\xbe\xc9\'D\xe3G\xbeH\x0b\xcd\xed\x1c,\xb5\xb4\xda\xcd\xf1\xbe\x14R\xf4/\xdd6\xd4\xad\xf2\xcf\x94\xe1\xa1/'
        b'\xb8\xb5\x7f\xaf\'\xb6\x06\x00\x92\xe5\xfc:"\xb1\xe26!%a9\x97\xc0\xces \xf2\xd2\xbe\xa9X03\xef\xe7\x8cj\x05\xc2\x0e\xd0U\x05\xebzE\xc5\xaa3\xb3\xcd\xd2\x1dy\xc3q\xec\x15\xde\xb9X\xb0\\\x14\xa5'
        b'd\xdd\x88\x81\x8f\x02\xce\xfds\x87<y,\xc6F\x04<;\x04\xdf\x82~n\x13\xdd\xa0\x11Vf\x05\xfb}\xc7\x9e\npM\xd8A\x0bM8"t\x8cd_\xc5\xc4\xd8u\x8b\xbd\x00\x08\x9aPl\xf8P\xeb%\xe1\x8d'
        b'Sb\xfa&\x16:p\xf5\xc5y\x1f\x81>16\xe0?w\x8b\x9e:/E\x18\xeb\xca,\x8f\x86\x96\xe0\xe4\xd8}\x7f\xce\xc8\xb3\xfc3$\x076\x1f\xcf9\xbb\xfb\x84\x11%\x1a\x18\xfe"t\x8a\xbe\x9a\xaf\xec\x87+?'
        b'\xf34\x00\xb4\x82\xa4\xc87\xa0\xe7@;\x93\x81\x08\xba\xb6\xe4\x1aT<7\xf0\x0e"/\xe6\x06\xfb~\x0bd8]W\xe7C\xb8\xbf\xea\xb5q\xf4\x95\xd9\xcd\xffJ\x85G\x8et@\xd6U\xbb%*\xdf\x93\xc0\xc6\x077'
        b'\x97Q\xb4\x13\x87\xc3]\xa0\xff\x04vC\x99\x0eD E\xb3\x1cE1)\xdd\xbb\xc1\x9b\xa7\xe4\xd9b]1\xd3\x84\xfa\xda;mc\x1a\x05\x0e\x06c\xed\x8a\t\xab\x06%esbS\xf0\xa4\xb7v\x82j\xe2\x003\xfc'
        b'\x00\xb7DJ9\x1d\x19\x8d\x07@\x88V\x97\xd5\x13>%yl\xf5\xbfl\x1a\xb6\x04\x1cg\xc1\x00\xb0_[[\xc0^o7\xb2\xbc\x07z\xae\xd0\xad\xfa\xcf\xd6\xef>\xa7h\xb6\xcc\xcaE]J\t\xc6\xb6\xb7\x05\xa4\xbe'
        b"\x07\xf6\xd8\xc3\xea\xc9/5\xcb\xb4M\xef?\xc9\xbcj\xe8\xafH\x11\xabK`h\xe2\x1c\xdf\xd3\x08\xd5-nRI\x1b\xf5\xb1}\xe6t\xf7;R\xcbOV\xac\xba\x89%\x00+\xec'\x15\xc0\xfe\xe6^sc\xdd!\x9b"
        b"VJcJ\x87K\xd3I}\xd4\\\xf6x>\x90\x11\xd4^\xc6\xd1\xb5\xe3\xdd\xc4\xdd_\x1d\xdf\x1a\xb8Q\x03\x0c^_\x826\x86(I\xf8\xd2%\xe7\x0e|\x99\x81\xf6\xe6\x04\xdfUd\xa5\xd5\xcbK'9'\xc5\xf7\x1c"
        b'Qo\x92\x1c4\t\xc2u\xd0\x1d\xb2~\x84T\xc13\xbdx\x9c%\\\xb9B\xbd\x9b\x0c\x0e?\xbb\xbb,\xc3\x7fB<C\xcd\x82DwS\x90W\x83\xd4u\xf1Ej\x13\x19\xb9v\xbc^\xb5\xd6B\xb8}5h\x96\xd5'
        b'Tt1\x8eZ\xf3"]\xca\xffL\xbe\xd9\xd5y\xed\x17\xd1\x8a"\xc6\xdbC\xc3\x03\xf3u\xd6\xdd\xd8@\x8dx\xba\xdb\xa7\x9f\xcaY\xd3\xd3\n\xaf\xcce\xfd)V\xb0l-Iz\xaf{/H\x9aWt\xd4\xd4;H'
        b'6\xb20\xf8\xd2l1\xac\x1a\x15}\x7fl\xe04h\x98\xaf\xa5\x9d\x05\x04\x1b\xfe\xfc9U\xdc\\@\x15\x199\xc4>\xf2\x0f\xb2\x88\xbb1\xd4f\xef\xb3dE\x06\x81\x87n%\x80J\x92\xc6\x0f\xa3\xf8\xdc\xb9g\xf2\xc7'
        b'S\x8d\xe1\xeb\xb4\xc3\x9fn\xdf\x8eO\xc9.d\x8fQ<_\xf3\xa1\x18\xc7JvEso\xc5\x90\xe8\xd9\xafF\xfdJH<A\x1a\x9c\xcav%)\x0b\x9c.\xdc\x1ae\r\xfeZ]\x0f\xa5\xc0\xc6\xe7@i\xdb\nB'
        b'\xdc\x12\xeb.\x7f\x16\x1f\x03\xc8;\x97\xe9\xfa\x8e\x10V)\xd2jiKa\x83`\xcd\xe7.\\\x06\xd9\x0cr\xba\xd9\xad\xe5"\x87\xef\xe0\xefGP\xff\xe0\x88+\xe3\xf8\xe0\xad\x8f\xee:\\3 }qh\x99\xaaWL'
        b'e+LNI2#\xeb\xaam\x9e\xdb6EXY74CN1\xf4\xab\xcc/\xbf\xa5\xdb/\x95\xc183\x8d\xc4\xeb\x00q\x18H\xbb E\xea\xe1\xa6x\xb5F<\xb9\xbdC\x1e%Y\\\xab\xda\xf5\x16\x0f`\xc6'
        b'SI\\\xa5\xd0\x88:\xed5^p\xfe\xef\xc9\xa19\xd4B%\xd8\xba\x87\xf6Ki\x00\xf7\x11\x0bl\x82\xcb\xc0\xf4\xa9@\xe4Gj\xde\xfd\x80\xad\x89\x9f\xd6a\x117\x87\xe7r\xb1\x80u\xde,FG\x88\xb3\x118C'
        b'05\x94\xca\xfa\x10\xaa\x13\xf9\xdc:Y\xb0m\x8b\x1e\xb1\x95,\xcc\x05K\xe3^\xb1\xb6\xc6\xa1_y\x87\xeam5\x95\xc3\x05\xbc\x85=1\x85\xab\x16-Y;\xcb\xfeq-\xc5QD\xcf\xf5s3\xfe6^=\x9d\xdc'
        b'|\xa5\x8d\x02\xcc\xbbX\xdc\xd7\xa6\x85:\xf9\xfdv\xb2x\xfc\x0e\x94\xb9b!_\x9a\x19\xed\x8f\xd5`\x0fg&\xc1\xda]\x968-tE\x8b\xff.T\xbd\xcf.(\xc1\xd5\xc7\xb5\xe0K}\xb0\xe0\xe33\n\x11\xdc~'
        b'}Q\x86K5\x9e\x88m\x8a\x17\xa9\x9fH\xd9Q@/\xff\xd5\xc0s\xba\xd6t?vT$\xceb\xe7T\xe6@:\xcf\xd8\x0e\xf1t\x93e\x8d+\xa1\x11\x00>\x8e\xda\xad\xd1\xb6\xb2\x04e\xe6\xd92\x1f\xb6\x8c\xc3\x1d'
        b'\xbf\xc8:\xc4\xbc^\xe7\x86\xd9W\xc4,\x0f\xb3\xe3j\x89\x87br\x12\x08\x7f\x1aX\xaf\x950b\xdd*(\x82vy\xb9z:\x80\x89\x18\x17N\xa0,F\x8daA\xd0\xf1\x0e\xf8\xdex5Q\xfb\xefk\xf3|\xdb5'
        b"\xe2\xd6\xfa\xcb$o?\xbf\xa1\x04\x1f\xceq\xed\t\x9b\xd8\x16\xa0\xca\x817'\t\xcc\xe7\xf6\x94\xf9\x94(EM\xd7\xe1\x1f\xbd\xb3v\x12\xae\x0f\x95\xac\xd6\xd6\x86\x98p\xbe\\\x87\xe5y\xdbSM\xd0\xdd\x8aU\x10;1"
        b'\xf0z\xdc\x8d#qw\x96\x89%\x05\xe2\xb5\xe5\xbb\x10t\xa5\xb4\x7f\x9bA\x06UZd\xd1\xde;"\xc5\xde\xdd\xe7\xa7\x82q\x8e\xbf\xcb\xf8\xf5\xb1\xb3\xa3\x936\xf5\xd7\xd8\xc7\xce\x0fn\xf8\x98\xcb\x9e\xf2Kk\x11\xf8u'
        b'\xb2c\x16\xcb\xb9.\xd0\x8c\xd5\xeb\x80\xcc\xed\x1d\xdb\x8c.x\x05%&\x16T=.\x89v<\x923\x99C\xe0\x1f\x19K\x8fV,\x9c\xb1\xc0\n\xdf\x9a!\x11\xcf\xc8\xf1\x91\xa11\xdc\x978\xdaK\x00\x1dp\xb5L\xa9'
        b'\xda(\xca=\x8a\xb7w\x0fP\xd4S\xaaQ\xaf\r2\\&\x85y\xc4\x11|C~x\xad\xb0o\x08(\xe7v\xc5+Y\x8e\x1f\x7fC\x88\x01\x83\xdeb\xa8\xa5W\xfc^\xc6\xbcM\xfa\x83\xd9\x18\xc5\xd6\x9f\xaf\xf4\x03\xfc'
        b'$\xd0\xa5\xd6a\xfe\xac\xfan\xce>\xe4\x08\xf2\x0c-\xe2\xa3\x88i\xcb\xa7\xe6Vy\x1e\xab\x18\xb3\xdc\x1b]O?\xde\xf0\x95\xc7\xe0\x1a\x9b\xab\xf6\xeb-\x99`qk\x13\xa7\x00\xa3"7\xccgm\x8c\xa3\xd2\x98\x87b'
        b'\xc5@\xa8\x93\x92SV\x1eE\xe7\x1dk\x02\xd0\x805\xac%\xf53\xe9\xdajA\xce\xeb\x1a:\x86\xc9\x96\xa2ny\xf2Q\xc1h\xe8\xa5\xf2\xca\x1c\x1eF\xdfA\xef\xbd\xbf\xc4\x9c\xeaL\x19\x00\xb5\xec&A\x9b\xd0\x17\xb5'
        b'\x10cZ\xc4q\xe9\x1e!\x87C\t\xbe\x05\xb1?y$\x7fo$\xca\xb4m\xdc\xe1@\x8a:\x1fMr\xe6\xacO\x18c\x8b\x0cg\x83\xb2\xd3\xa3y\xd9\xd1\xdfu\x1e\xdc\x11`x\xe9\xf5\x92\x03z\xe7\xae\xc8\x83\x0c\x9a'
        b'\xca:Rb\xa3C\xba\xe5\x0b/\xf1\xa9Q K\xc0E\x08\xba|<0\xdaIT\nT\xef\xd7\xf1\x90HD%0\xff\x9e\xec5oQ9\xb6\xce\x05\xbd\x02\xd4\x8f>\xfc6\xcd\xc2\x9dAx\x10R\xa4\xfd\xa9\xfdq'
        b'2\xd9\xbb8\xce\xc1N\xf1\x1f\x12\xf0H\x0e\x03\xb9\xe0\x01\xf3\xbf5\x9dem1$I\xbd\xd2s\x05\x1dH\x9d\xf7\\5\xf6\xa3?\xc28\xa9\xb6\x98s\xe9E\xb1Tt\xb1;\xb7@<Z\xdb]l~\xbaV\x04F'
        b"\xbf,N\x02\xdbE\xb2Jqx^\xe2\x141\x91O\xbd\\\xe5\x9d\xaet\x15~G\x87\x8d8RG!\x1e\xb0\x80\xd4\xd7\xf4\xb2'\x15\xf1\x81,\xdc\x1f\xcd\x01\xf0\xb0\x82\xfeE\x17/,\xc2P\x96\x12o\xe7\xd2>\x16"
        b'_\xe1z\xee\xd0\xac\xa5\xac\xa9~\xc3\x1d\xe4\xa5\x9d\x94\xcdXV\xf2`p\xb6\xee\x99\xca,\xc8\xb8`\x8e-JF\xa15\x88~\x83oHL\xea\xbe[\x81\xf7\x98Xg\xeb\x00\xf3yU)\x0b\x9c\x90\xac\x01j\x18e'
        b'\x92~\x85\xf1\xab\x8a\xdcY\x17\xac\x94\xd3\x8b\x01\xfb\xeaK\xf7r\xfc\xedF\x0bj\xc1\x0e\x83\xfc\xa1\xf8\xb4N\xb9\xe1\x1c\t4\xb6v\x9c\xe6\xbb\xb0\x02w\xbf\x12G\xc5,\xee/\xa9\xe3\xc5$\x01__u\xa5\xd0A\x0f'
        b'\x8b+45\xbeRW\x8b$\xbc\xedBC\xad\x0bY\xf8\xf30\xac\x1e*\xa9g\x81\\\tO\xccWa[\xf4l1)U\xeb\xef\xa6\xb5\x13\xb4,\x16\x1c\xff\x95\x08v1\x836\x9e\xcf\xf4;\xfc\xa3 \xd6\xf9y\x03'
        b'\xa8;T\x8c\x899\x8b\xa7\x9c\x8c[@\x17Vm\xda,\xe0 \x14\x00\xf8\xb8\x0f\x99\xbb\xdd\x14p\xdd\x8c\xe9\xb1\x0e\xd2\xa3i\x8a\x06\xe7$\xbd\x1a\xaeVIvFL\xbb\xa3F8\xd0QFP\x16\xd7\xa3\x07y\xc7\xac'
        b'\xc1\x9b4r.P2EWdy#+K?\xd3\xdd\xea\x81h+aG\xe2\xebhz\x08|%0\x91f2\xaf\x0e\x10\xc9\xb9!T\xa2\xa7\xa2\xa8{\x97\xbbJ\xc6\x8d\xfb\xc8h\x04\xd3"y+r\x90\xaa\xf5D'
        b'\xfb\x8b\x80\xb6\xd8GD\x96L\x82Is\t\x10\x98\x08|\xc0\xfd\xd3\x81\xb1\r+`\xa0HP\xe8V%|B\xe2ROX\xaf\x19\xe8\xec\x0fD\xec\xda\x81\x13`\x0b\x93\xd0\xd9x \xbc\xdb\x88\xc9\x10\x97\xb10\x1b\xce'
        b'\x12\x1d\x8bnh\xb9\xae\x02\x17n\x191\xe6\x05CV\x10a\x1d\x17)\x9b\\\x9d1\xf4\x0bB\xf8\xfa\xe2"\x8cQ\x0b\x9be\x1441\x07\xc3\xe1+\xd7Q=\x1b\xe7^!}*$\x04\xa4\xab\xb1\xea\xb6\xb33\xb2D'
        b'\xe7\x86\x95\x1b)N\x80\xe3\x86\xdd\xabS\x80K\x1d\x8d\x93\xf8&\x17E\xc7\xb3S\xd4\xdd\x8cH.\xd4\xbb\xca\xcf\x00\x8fE\x1d7\xa3\xc9\xa1\x88#`#F!bT\xfe\xf6\xc7\xd3\xd6\xb5\xb6\xcb(?+t`\xdc\x85'
        b':\x161\xcc\xb5\xc1C\xb8?\xb4\x88\xe1\xe8pv\xd1\x0e\xc7S:\x11\x14Dj:p,>d!QEQ\x03\x93l^\xbb\x90\x7fb\xe33\xe8D\xeb`\x89\xb5\x8f\xa2G?K\x16v\xef\x87\xdb\x9f\xbe\xbfU\xe6'
        b'\x85\xc5\x13\xc3C[\xff.\x9eN\xf8\xb4%to\xd4e\xfd\xb4^m\x7f\x1c\x8c\xfc\x92\x11\xd3\xa0\xdd\x82\x88)\x01\xa1\x03>\xd8\xb6\xca\xf4\xb8\xfe=h\x10\x88;~ea0]!\xd7\xb2\x17\xe1\x9c\x14\x9f\xcd\xda='
        b'\x0bl\x06\x9c\n\xe5I\xb7AB\x96c\x88\x98\x04\xaf"\x9fd\xce`\xcb\xc18E\xb6\xd5&8Pq\x84\xad\xa3\x8d\xfc\xa9h\xaf\x10P\xec\x1a\xf4\xbbFClU\xd5&\x17\x98}?\x95\xfcH\xf1d\xd4u\x08\xd9'
        b'\x9c9\xf5 \xfa\x8f\xa7_\xb8\xbcq\xf2\xb5RY\x10+\r\xba0\xc3b\xa1\x8f%Ut|\xe8H\xf0\x08\x16V W\xd3\x1cf\xa0\xfb\xa4\x19\xa4\xc2R,\x1a"YI\xf0y`|\xe3\xf9L\x0e\xf3\xd0\'\xb3\xbe'
        b'\x83\xd5\xb1<?u\x9d\xbc\x9aI\xa9\x13\xd6\xba\xbd\xad!\xfe\xa1\xe8\x1dM\xee\xd8G6/\x04j\n\xa5\x12!\x86\xbff\x9e\x9a\xf3\xc9*\x868u\x83W\x7f\x0f\x00K)u\xc8\x95HV\xa6\xb1IL\xa6\xad\x1e\x85'
        b'\xeb1\xa8\xd8\xa3\xfe\xa6\xbf\xe9\xcf.\xdb,\xa05\xc0\xe7\xd5\xfaa\xe3\xa0\x1a$\xa5\x1a\xc7?\xf8V$\xec\xafj\xaar\xach\x92w\xa2\x9d\xca\xf2\nN\xfd\xe9\xb9\xf6\x81\xe4\x04\xdb\x13\xe1i\x15\xba\x1e\xccv;='
        b'!\xc7S\xaa\xa1\x84\x04\\\xc8\xb4(\xa1U\x86W\xe7p\x9a\x80!d\x93\x90\xbd\xb1\x17v\x0e\xb5}7\x8dj\xd5\xef{\x16\x18l1LQ\xeb\xf8\xdc\xa7xs4\xc7\x81\xd0\x804\xa9\xee\xc3+\x96\x0c7rG\xcd'
        b'\xfd\xad#Z\xf7\xd2\x9d\xa0G\x05\x1e\t> \xaa\x97\xf7\xa7\xa9\x005_\xad\x13\x0fPH\x82\x10\xee\xcd\xa0n\xac\xa5f3G\x83\x99\x8e\x10\xb4\xf3\r\xf11\xad\xe8\x87\x8a\xa1+\xe5:q\xb4M\xcd\x9b\x16:vf'
        b'\x9d\xad\xcf<\xe4\xf8\xc6\xa8\xc9=\x0c\x17^gloK\xc8Y[\xdbz.\x98/y7\x8d\xf3\xd8n\x03\x86n\xc5t\xcd\xda\x19F\x15iVbJ\xa9\xf2\x91\xaa\\\x9eo{(\x1e\xe2\r\xdb\x80\xc9\x95m\xf6\x18'
        b'\xf0\x9d\xcd\xa4\xab\xf4U\t%\x80\x93\x0e\xd4\xb8\x05\xeb=\xc6\xb9?\xf1\xdfW|&~A\xb5+\xfb\x10\xbc\xf9\x89\xf83\xf1\xf3L\xc5\x08\xa9\xd2X\x0c\x00l.\\\xcb\x8a\xd2T\xd5\x1c\xd1!\x82\xde \x81\xe6\xc5R'
        b'\xcb\xc2\xd3V\x91\xe0\xc5\x8a\xbeSa[\x9e\xb9"C\'\xc2\x92\xe60x|\xfd/\xfb\xe0\xbe\x88\xcd\x11\xfa;\xbf3[uQqc\x1e\x8a\xca\xca\x8f\xc7H\xbc\rC\x06l\xd8Z\xcf\xc9\xfe\x99\x96\x0ffo\x0f\x87'
        b'\xb1^`)([2\x12\xf6\x19\x88\x7ft\xf7-\xdd\x8b\x08\x0c\xaa\x195\xadj;R\xa4\\Q\xb03\x81\x17\xa6l\xc1\x9b\xb4\x93\x80\xa4\xde\xe27z{\x99\x9e\xedZ7\xa6\xab\xe7\xaf)L\x07\xbf\x88V\xae\xe2\xf4'
        b'\x10\xc4\x85+BB\\\x81\xcb\x88F\xb9\xb7$\xce\x9b\x98t|mU3\x11F$\xb3\x01\x15\xe3\xa4\xd6\x8c\xbd3\x94\xc7\x8ey\x95z\x18\x13\x8a\xf3\xca\x16\xb4al5-4\xbe\xd5R\xc0\xd1\x1b\xbf\x1c\xf1\x0c\xab\xeb'
        b'\xeb\xe7#\xc9&V\x03\x8f\xde\xa2E/h4\x9f\x03\x1e\xa3\xe1\t\x80T\xe5\xe6\xf8\xde\x97<r/\xdc[\x01\xe7\x14K\xbeKBcU\x96\xa0\xe7\xd4CD\x89E4\xdd\xe77\x03\xd9\xfa\x10\x18b\x14\x8c\xea\xca+'
        b'\xc9\xf7\xf2\x88\xe2\xb9r\r2Pb\xc3AR6u\xee\xb6\xeb\xd9>C\x0f!\xafk\xb3"\xc5f\xf3\xec\xc3\x1e\xbf\xea}\xef\x1d\xfc|"\xdf\xd5O\xe4\xb3\xc5jQ\x8e\x7fg\x03Q\xa9\xfc\xc3.\x11\xb5\xd1d\x8b'
        b'wd%\xe2,@\x96\x07\xaac\xa6\xb9x\xe5\xd3\xaf\xb5 \x9dk\xe13\xb3\x15g\xb2IY\xc4\x1c\xa1[\xb4\xd4\x9eW\x96i\x9e\xe7\\\xfb( [\xf4\x87\x07\r\xed\xf8\xb5nD.\x0f\x80L\x10\xcd\xea\xe2\x86\xce'
        b'\x15\xec\xf8H\x8cxc\x84b\xeap\x98\x92\x9d\xe1[\xb1 \x13\x1b\xde)\x80\x88\xa0\xbf\x1f\xd2\xf1c\xf0\x91k\x19\xc5v\xb9&\xae:\x04\x8d1\x1f\xfd,>\x80\xc3X\xec3\x1d|t\\N\xbf\x85\xd2&\xb9\xef\xf6'
        b"\xdb?\xdf#\xa0\x17\xd1\xad\xa6{aS\x89E;\xa9\x945\xc9<\x08\x8d\xfa\x01\xd5B\x0f'\x8af\xe7\xb0\x9a\x19\x80kc}\xe3U\xaao\xc7\x02\x0b\x1a\xf0\xe8^$1)\xb98\xe3\xb0\xbf\xc7s\xf0\x88\xc1\x0b\xa0"
        b'\xd7-\xc4\xaf9\x99G"\xe0\xd3\xcc\x9dqB\x18\x97%\x98\xc9M\xddDz\x83\xef\x86-\xafF\x99\x9e\x06\x9b\xe4\x7fCv3\x1c\xda\x92\x1c3\x95\x9f\x96\xae\xfeAn\x84P\xfbIa\xadm\xd5[\x824~\xebx'
        b',D\x9a\xac\x9f7\xe8\xd1\xc6\xd7\xe7?\rI\xf0F\xcf{\xad+\xea:U\x05Y\xa7\x9a\xdc\x87rf\xbb\xf2J\xc0\xe9\xb77\xb8\xe8\xed`g\xfa\x13I\x87\xa5\xc6..8$\x8bO\xfe\\\xbc\xfc?\x1c\xc7\xb0a'
        b"\xa3\x9ah\xba\xcdQ\xc7\x17H\xd6\xf3\xef\x88\x82\xda~\xa8\xc3m\x08\xebn\x1a\x9f\x12}T\x0f\x96\xd6\x90\x80<\x9d?ul\x8er\x89\xb2\xe3\x9c]\xe6y:\xc0E\x14\xcd\xd3y{G\x03\xec\xe3\xd9'\n\x1d\xac\xe7"
        b'\x8c\x87\xbdI\xa2t\xb0\x1b\x96\x8et\xbd\x10N\x16\x1e4\x9d@\xefs\xf2\x94\x94\xcf\x94\xa2\xcar\x91>0\xec\xbb\xb3\xe6\xf3\xa8Z\xc3\xc85K\x12`\xdc\x0c\xe9.\xa8\xd3h2\xc5\x1d\xc8\xd4\xa2\xca\xbe\x97\r#\x9f'
        b'\x11{\xd5J\xe7\xab\x83\xa8\xcb\x11\xb0\xce\x86\x9e\x84NBM\xcd\x9d\xb4DH\xe6\xf2B\x0c}1\x00\xc9\xb8f\xf7 c\xd5\xde\xe8Zb\xa4\xbb\xe1\xd4\xb1\xd3@\t\xc4\x04\x80\xc2\x04\x1cX=\xe0\xb1\xd0Q}\x13\xc6'
        b's\x10\xa8*V\xf4d5\xd4.\xe5\xf5\x82c\x10\xf1\xf7\xee{\x82\x11\x86\xadB\x1f\x94T%\xd3\xbaw\xa6Q\xeb\xd6\x12\xbc\xa69\x11 \x1a\x87p\xf4\xd7\rd\xa8\x18\x9f\xeb\x99\x05\xb9=\x8d67s\xb9\xb6HW'
        b'\x85D\xe3(%\xf4\x0ev,\x87\x9c\x9fjtjem\xe5\x07Yb\xb3N_\xdd\\D\xc4\xbe\x1cv\xa2\xd8\xb4\xfe\xf6\xffp\x0c\xe1\xde\x8f=\x93\x03\xed\xb0\xc5\xe8"1^\x85Z\xb7\xd9^\xc0\x96\x9a\xc27\xe2]'
        b'`\xf1fu:\xff\x9f\x0e4``\xa1\xbb<M\xa2\xb7\xbc\xb7\xe7\xaa\xd9\xebK\xaa|\x95\x1c*\x83S\x95R\xaf\xc1!\x821\xf7Io\x8d\x9d\xf8nM6\xfda\x9f\xdf\x88\xe5\xdf\x1eK\xa8\xb7Lu4\x1a\x1f\x9f'
        b'\xed\x8d\xed\x03=\xd3p\x97\xed\x88\xa4\xa1\xd8\x07\xc6\xf3\xd2nU+{\xbe\xb4\x88\x03\xbe%B[\xa5\xdby\x07\x0bhq\xe9[\xd4\x14\xb8\x15i3\xf1c\xbe\xe8\x90\x0b`\x87\xf4K\x13#U\xb9\xdd\x0e\x96\x86;\xe7'
        b'\xbe\xda\xcf\x8ai\x12\xdc|+\xbb\xd7!\xb4\x97\\\x03"\x8fi\xc3\xb4\xc9{i\x8ap\x9a\xa5\xdc"\xa32\x02s\x86\xb7\xddS.I\xdb\xcaz\x82:D/\x8b\xd2\xfe\xcd\x10X\x95\xfbA\xb8"\xec\x1a\x80\xb5\nL'
        b"\x95;oA\x01D\x1b\xcf\t\xc3\xff\xed.\xa3Oh\xc9\xae\xc3\xdd\x7f7Pd\xb5\xcc^|\xf1\x8e\xf8\xf8\xf1+\xddM\xaf)\x97\xd2\xbbV\xdb\xae\x97'C6^\x99N[\x0b\xfa\x9a\xa6\xa6\x12\xc3\xb9\x8f\x12<\xa0"
        b"\x06\x9e%\x87\x96\xd7\xd3\t\xd9\xd3\x14,wK'\xf2\x83xo\xcc\xa555\x00\x184\xf8m#\xe6o\xcaG\xab\xda\xb3_\x13\x16\xd6/\xb1\xac\xd5\x1bf\xbc\t\xe1\x9aDZ\x8bkJ\xa4\x17\xf2\x1f\x97\x04\x9aE\xff"
        b"Q\xa9h\xb3:\x8d^\xab\xd5\xdb{\xd6\xb7\xc2\xa2\xb4}4\x03\xa5\xb2\xedBS\x87\xf5\x8c\xb8\xfa^\xcc\xafL5\xb4\x0c`\xc7\xec\x97Q\xc4Vw\x99B\x0b@tH\x9aQ'9rK\x02\xe6\xc9u\x08\x04\xa8e"
        b'\xfb\xe7\xfd\x81\xf9\xd7T\xc2.\xea\x89\xdaX\x19,9\xa8\x98\x01k\xb0\xf3\xb1O\xaa2%dy\xe3\xa0\x84\x88O\x84\xdf+\xec\xf2\xb9\xf4\xfa\x1fV\x8c\xfclV\xd0\xb4\xeb\x9b\x115\x9a^\xc2\xd6N\x17%4\x8f>'
        b'|\x8bx\xb82ndd\xc7)\xfb(\x1a\xf3\xf8n\xf3\xf9\xbc\x0e\x9a\xa2\xbdq\xd7\xcf&K\xabNF\xefc \x94\x7f\x19iB\xc5\x98\xa6\x07F\xf4\xb40\xff]\xcb\xd8\x8dV>\x9a\x93\x8f\x98p\xa9\xb9\xd3)\xdd'
        b'\xa5g\xb0\xecQ\xf9CQ\xb0\xd9M\xbd\x97s\xf9=\xc8\xaeT\x8cD\xb4\xf8\xde\xd2\xc4\x16r0\xec/\x84W\x19\xbbv,% \x1e \x88\xc7\xf0D,W\xdfd\xcc\xdd\x95\xb48-\xc3{\x0f\xea?\x1a\x15\x12V'
        b'n\x9b\xf3\xf4H9\xb5>cH\xf1\x0c\x82\xb2C\xafN\xfe\x16\x1c\xcf\x10\x80\x80\t\xd9\xd9]S\xe1|\xd5\x7f\x054:\x97\r\x99o\x81Y\xe953F\xdb\xf8G\x05\xcb\x11@\x81\x91\x98\xec4F\xe5i\xb6\x82\xf1'
        b'\xe6R\xd8\xc6G\x83Ip\x1b\x90\xff\x94\x03V\x97\xe8\x13\xf3\x8d[C/.\x1f\xae+9\xb6\xdb}\x85\xca\xcb5T+\x8e\x07\x1e\xc2\n\xc7|\xcd\x9b\x07\x84\x84\xf8\xc9S\xf4\xbf\xba`\x8b]\xadZ.h7\xdf\x1d'
        b'5\xe8s,\x91n\t\x97i+\xba\xfd\xcb\x83!\xc2d\xac\xd2\xcfc\xc4O\x83\xf8Y\xfd\x84\xac\x0c}\xbc\x88?\x02\xbf\xd9\xdb\x83\xf9\xddH\xed\xeb\xa9\xdc\xed\xf4}\xec"\xcd\xa8\x916\xe9\xfd\xf9\xce_\xa7>p\x1f'
        b'\xe1W\xa8\x96\xc7\xc8\xcb\x0bkw\xfe\xc0Ypi\xca\xeb\x8e\x97|/\x8c\x84\xebH\xe3\xb5\xc7\x95:[$\xce\x96\xe9H\x16$\x88\xe69\x14\xd8\xb5g\x1bCo\xe9\xdcI\xbf\xe2.O\xb7k\xcd\t\xc5\x9d\x8f\xe5\x05'
        b'\xe6\x1cOY\xd8\xf6\xbc\xe7]\xa0:f\x0f\xdf\xe9\xc7N\xff\x86F{R"\xc3\xb4d\xb3/\xcc\r\xdd,\xde\xe5Dr\xb7\xca]w.\xf6\xc1\xde\x8e.\x04\xfd\xbe\xeb\xc3kY=|\x90\xe4,$\xe3"k\xed^'
        b'e\x102\x89\xb1\xdeF\x99\x00\x1a\x08S82\xa4\x8d\xc2$R\xdcZ+\xbcEW\xff\xff\xb5\ts\xb3\xfb\xdd2\xd8\x86\xfe\xfa\x8aH\xcb\x14\xe0J\xf4\xcb\xa7$\x9d\xe0\xe7\xc24\x07?\xb2J| \xccm\x91\x9f\x16'
        b"\xbf\x81O\x8d\x08_\xd6\xba\x80\xd8\xf6\x0c\x85:\x9f\x84O\xd8\xae\x07\xf1/\xc3Z\xa4\xc6\x15\x8eod\xc6\xa5\x9b\x1e'\xe1\xdb\xce~z\r\xa4\xaa\xbfuqL\xe7\x16\x86D\x100%\x98\xe8sD\xe6\xd4K\xb9\xc6\xc2"
        b'\\\xd3\xaa\xc59x\xc6$``\xb3\xf2\xe0\xc7F0\xa6H\xdb\xf2O)\xf8\x10\xa4\x9e\xd7!\x0f\xed\x02x\x14N\xb5\x9c\xa4b\x82\x93\x8e\xbf}I\xcaj9\xc1\x9cp\xbc\x07aB\x01o\xf0/\xa7\xfa]\xcbu\n'
        b'\x11\xca\xfd\x10\x02\xe2!\xd0\x1d\x00\xd9\xd0\xb5\xa4\xaf\xb0Q\xf1\xac V\xda\xd0xQ\x8e\t\xf0\x1b>\xe2u\xe57^\xfd\xeb\x80\t\xed\xa5\xf36\xb1t/E?\xa8\xd1k\xd3\x1d|v\x02:Q\xa3\xe8\x00\xe8&\x9b'
        b"h\x16\x03\xfb\x7fG\x99\xaf\xd4\xd6r\xed\xa9\xa2\xa2\xcd\xca\xa3\x83\x06\x86_q\x9d\x97X\xedT\x8b't\x81\xba?\xb5\xf9\xe3\x8b\xda\xb4\x82\x91\xb1\xbaOf\xfd\xba\xc32\xb7\xa4\x89\xeb\xe4X\xfc\xd5\xbf\x86\x00\xff\x00\n"
        b'\x15{\xf0W\xa4\xb1\x7f\x12<}\xaa\xf2\x8f\xd8J\xff\xb0,\xfe\xa1\x8a{o\x19+@>\xcbc\x83\x8b\xa1\xd5G\xc0d\x9f\x1b\x1b\xf4\xec\x92]\xea]v\xe1\xfew~\xed~t\xe6rz\xb93\xe7\xe9\xe1\xde\x13\xe8'
        b"\xa3\xb0H`\xe6\xd48#%F\xc6ud\xc8F\x80'u\x8d2U\xe6:\x19\xcb4\x96\xa9B\x94\xec\xdcs\x10\x99\x8b\xea\xb28}\xbb\xd8\xaf\x17-\x11|\x87{\xb53\x97\x05\xa6\xa8\xcf\x9e:\xd6`>\xebx+"
        b'NRbe?\x92\xc2X\x9a\xa5\x1c\xb7<\xd6CXN\xb6\x10\xd1\n~BW\xe4P1\xfc\xe6fa\xbd\x8f\xd9p>(p\xcb}6\xb5i?\xbd\x99\xd3\xf9{=4\xd1nd\xa0vkP\xea\xf9\xcd\x80\xcbg'
        b'=\xda\x94\xa6\x8f+\x82\x1f\xca\xc2W\xa3\xba\xc5UE\xe1DLB\xaf\xfc\xa7en\x81\xd9\x01\xc4\xd0\xe7\xe8w\x8a\xa1\x9f\xe7#H\x81\xe2\x1f\xe0\xaa\xdeb\xe2\xc4l\x874W\x02\x91\xfd\xee\xf1\xfb\xc5\x9dYt\xba\xb5'
        b"M\xa7;\xfd\x05\xb2\xd8\xf1\x1b\xf8\xbbz\t\xfa\xbb\x02\xe6\xba7@\xd62\xfe3;\n\xeb'\x7fe\xf3\x86\x15\xe0\xc4\xd6\xaa\xd9\xad\x03O\x8b\xc5sD#\x9ey\xaeO% \xc3J\x10f.F\xc4\xe0\xdaJ\x9bm"
        b'\xe9=\xeb\xfa\xe61\xab\xd2\x1fE\x97\xe6\x88\xc2\xaaub\xae\x8e^\x0f\x945\xc2:\xca(3#\xbb\xc1\xb9G\xf1\xbaT2AV0^\xf4\xfcX\x88\xc0p\xbf6\x9e\x9b\x18\x7fx\xfat\x15\x11\xa8\xe7\x80\x95\xe8\xe4'
        b'\x93\xb9\xaa\xc05=\xb5\x7f\x17\x063\xb8\x86\x7f\xde\x98\x19\xaf\xc4d\xab\xed\n\x8b\x0f\x9c\xcd\xe5\x8f\xb9ej\x93q\x84\xe0\xf4[\xa4s\x08\x08\x05Dd\\\x10\xbbA \xdcu9~sT\xf9L\x87\xee\x9c\x87\xee\xa8'
        b"1\x8bF\xa2\xadU\xa3\xfc\xd71\x95EhIq\xdd\xeb\xceE8\xb1Gs5H\xfb\xaa\x94\xe6\x0b\xa5\xb7'\x98\x013|U\xceeB\x18\x06\xe1\x08\x8br;\x91Uan\xbf\x8fq\x18y\xa4\x8f\x9et\xc2:\x86"
        b"0\x84\xe1U\xdd!(\x02'\xb0\xd3\x1d\x91\xa4h\x0f\xdd\x0f\x001\xdb\x92,\x18\x06\x14\xb2\xc4\x19&\xf6h\xaf\xc3;D\xfb\x0e5\x8f\xdb*\x04\x06U:9A\x11\x1b\xd2\x15\n#7r\xe3\xd4\x94+\xb2\x19\xaa\xbb"
        b'qOBk:\x02\xb8\xc7\xfa\x89\xaa\xc4\x96\x1f\x87|\xa5\xd7\xd1\x95\x9b\x9b\xa87\x16\x9c\tFn0\x03*\xdb\xfd\xc1 V]k;\x18\x81\xdc\xd9\x17?\xe7(\xd2\xb6h\x05\x83+\x12?G\x8c\x8a\xcf+\x9f\xb8\xbe'
        b'd\x106N\x7fM\x07\xfd\xbayn\x04\xa7LZ\xa63\xc9"\x15\xab/\xc4SM\xdcL\x00%\xfc\xaf\xebP2\x13z\x8eCSF\xaa\xcc\x8d\x1a\xf1\xc8\x1a\xf0\xef`\xb6(\xa7\xe3X\xa5\x89\xf6\xdb\r\xecVR\xb3'
        b'K\x1e\xe6\n\xf5\x88C\x1f\x8b\xcf\x11\x92\xe0\xb4\t\x94\xa7\x17\x02\x018\x8e\x08\x8f\xa8\x9e8A?\xf6\xf1\x13C\x92\xe5Rh\xf0\x89H\xfa\xa8\xe3\xa0\x10\x16]\xb6\xecX\x02W[:\xbe\x0c>\xe1G$\xc2\x9d\xde\t'
        b'\xd6q\xf4\x07@\x98\xbf?29\x1b2:g\x86\xdd\xe0\x997W\x16;X\x14\xab_\xe6(\x1d\xdf\xdb\x99\x03\x16\x19Cp\xe4\xbf\x97}@\xda\x0f.\xca\x95\x839\x88\xfb\xf1-\xb1\xf8y\x7f\xcd\x03\xc0\xa6e/\xf5'
        b"\xeb*\x81\xea\xa6\x0e/cb\x87^\xf3RO\xa0\xf2'%\xfd2\x9b(\xa1`\xf5%N$2>'\xf6\xd7\xad~\xc3\x06f\x0c\x07K\xdf\x98Y\xe9-\x9d\x851\xdd\x81\xc3\x00&\xcbUt\x8fk\x95\x8bghh"
        b'v\xa7\x8cF\x7f\x14\x0bd\xcd\xd6-\xaa\x85\n\xfd\x03\x1e\xf8\x1e\xb1\xcd4q\xcf\xd7\x80\xa1\x1fj\xab\xb8k\xf6\x10\xef\xbcD\x9b\xc60c\xb9\xfa\xaa\xdb\xec\xc1Z\x90\xa9\xac\x0e\xb7NC\xaa\xe0\xb9^q\xd5\xa3\xb9X'
        b'\x0f\x83\xc2\x12\x86\xb3\x01\x9b\xe5:K\x18\xdfM4\x8a\xe5d6(\x96\xef\xf9n\x8f\x17\x16z}\x02\xad\xeb"d&L\x9f\xd3\x17e\xc0\xaf\x1d\xf5!GE\x00G~\x12\x1b6\x82~\x02\xd7E=\x9b\x15\x8b\xd6\x87'
        b't\x95^f\x1b&\xc3(f)i \xc5S\x9e\xd9\xa9\x00\x16_\x90\xae\xb6\xee\xbe#Y\xeeGD\xabRU+F\x1f!\x8c_\x1c\x8f`\xdd\xe8\xff$a_2[\xec\xb7\xcb\xb9\x80\xaa\xdaC\x1f\x12\xb3\xc2\xc8\xda'
        b'\xc6\xea\x84\xdbF\x8a\xf4e\x12\x1d\x95r3\x04$L;%T\x82O\xfb+\x8d\x11\xcd\xf8hWj\xc2x\xaa\xe2\x8c\xc6\x92\x93^\x8a\xd7\x81\x19F\xea/\xe8!{\x8b\x98\x92r\xb14\\\x0f5i\x19I#\x0f\x0c'
        b'\xc0\xa8F4q\xd1j\x15\xd7\xb6\xd9\xaf\xafMq\x0b\x134\xff\xe3R\xe5R\x13\xa1\xa8\xd2!\x96\xdfk\xf8\xd40csJ\x1a\xca\xcd\x98\x12\x84\xbfA\xc1f@\x0er\xf4\x83jD\x19j~H\xf3\x80\xb7\xc4\x84\x12'
        b'm\x99\xba\x06\x0e\x08\xee.\x81m\xa8\x02\xbe\x038\xd6\xe0Bf\xf3\x9a\xef\xba\xd4s\x88a\xac\xeb\xaf\xba\x85\xaf\xd7n\xa5\xfcI\xea\x9d\xcfY]\xb5\x84\x93\x088w\x102\x82\x9a\xbd%$\x12\x0b&\x18\xf4\xd0m\xad'
        b'\xa0\x0f\xd7\xc5\to\xe3\x8b\xd5*\x1e\x1e\x91\xa0V.\xd0d\xf95\x81\xa2\xbe\xef\xf0\xd8:\x9bk}\x96X\x85\x84\xd9\x9c\xaaM#qLbT\xdf\xd5$\xf1\xf9I\xe0\x8a\x9d\xfeM\x11%w$l\x13\xab\x83\x18\xf8'
        b"\xff\xea\x07K\xec\x14\xbb\x93\x1d\xc6\xe8\xd6>V\xc4Z\xcfA'pH\x9bG\x82\xd0\xb2\xd8\x17q\xb7\xbf\xbe\xc0e\x0f^\xed&h\xa7^\x03w\xe0R\xfeVi\xc9\x18%\x0f\xfb(\x00#rn\xc1\x15Wys\xa7"
        b'\xe2\x88\xf2\xfc\x8e\xa5\xe7\xaa2P\xd4R\x88W\xb4+\xd5Z\x90;\xbe\r\rYK\xfc\xe5\x89\xe8\xccW58v\xc7aK^Whck:\xa0\xeb\xf0\xc6\xd2S\x97<\xfa\xfe3*p\x9e\x1b\x05\r\n\xa3A\x13'
        b'M4\\\xbd\x18\x83\x8b\x8b;\xa3i\x9d\xdbh\xa5_\x83\x01\x06e(\xc6qm=G\xfc/\xe4 \xe09\x82\xee\x0b\xee\xab\x10\xa3C|1\xfc\xd5\xfd\x9f\x19.\xf5]%`~\x1a\xe3\x97\xf5#\xfd;\xa5\x05\x03/'
        b'S\xf0i\xf6\xca[\xf3\x99\x95f[\x90\xb6U\xf0\x99\xfe\xc6!\x93\xb7\xdf\\8\xbeS\xdf\xc3\x90\xd3\x84\x9f\x07\xce\xc4\x08M\xc6Q\xb6\xa8J)\xa8T\xad\xe6g\x94Q\xfaT/m\xb7\xd10qC\xbfq\x13\x05\xb9'
        b'*\xbd\x9d\xf4F\xf3:M\x96\x9fm\xd4\xfaZU?\x18\xd1\x98\x00GB\xa0\x18\x7f\xfcO0\xf4\xbc\xd3F\xd50L\xce\xc38\xdc\xfa\xa2\x05\x82\xa00\xe0+Ej\xa8uH\x9b.\xad\x02\x13\x9bj\xc3b\x0b\rL'
        b'Z\x03\xcab\xa3lP\x08\xe2\xb4\xc3\x87\x17`\xbf@8\x87\xa6\\m\x93\xa8\xd4O}\xcd}\x15\x06\n\x06k\xb0Sw\x9c[\x0e\xcd\xbcA0\x9b\x04\x1dU~\xa1\xfdZg\xae\x147Df\xc6A\xea\xf2%T\xb0'
        b'>\xaaw$@\x9e\x15g\x91\x0b\x99\x96\xa8\tV\xd3\x92\x1f\xe0"\xcb\xd2\x9aOn}w<*\xba;\xa4\xc0\xdf\x1d;\xe1u\xef\xf8y\xbcJW\xe1\x8fo\xa6\x1c|AxN\x8e\xd2\x1a\xdd}\xa1\x0e\xba\x19\x82\x06'
        b'\xf7(\x8d\xc9"\xfd\xf4\x95\xa3\xc8\xf5\x85\xbe\xffGW\x0bw\x9a(\xf0~\xcc\xf3\xb5q\xc8\x9a\xce\xaf\xebsk&\x97\'\x8b_\xe9\xbd;\x14\xfd0U-,%\xb7\xb5\xa5\xe6\xa5K\x0fs\xcaL\xf7D:nw@'
        b"\xd5o\xaf\xa9$\xda\x1e\x0b\xd9:\xe4+\x00\xab\x12\xe1H\xd0\x00\xcf\x16d'7\x90\x7f\x19\x01\xb5\xaa\x8d/\x81\x94][\xac\x1e\x10IQ\xe4\x11z\xf4\xfc\xb2\x1f\xfb\xc6\xe70\xf9\x11&\xce\xf8\xa3w\xd8=\x12'N"
        b'\x9a\x82\x04|\x10\nh\x96\xa4\xc0F\x91\xa8\xd1\xcd\xec&)6-\xe5\x8c\xa0Z\xeb\xd7\x8e\x7f7\x87\x1d\xfas\xdb\xe6/\xfd&\x07\x0cq\xfb\x0c\x0cl8\xbf \x02B\x06\xcbP\xa7\xf25\x92JD0\xb3\xb4p"'
        b'\x17\x11J\'\xd3\xaf\xf0\xfd\xbd\xf7\xad\x95\xdb\x8e\x0cp\x12[b$\xac\x1b~\x16X)Y\x18A\x80\x03\x99g\x02\xdf\x0b\xfc\xa1LD\x14\xc6+\xf1a\x1a\xc2X\xff\x8d\x93\xb6\xb4"\xbe\xccP\xc9\x17g\x14\xa9\xf7A'
        b'C\x8a\x8d\xd7\x03\x05A\xc6c\xa3\xd4"\x9d\x8c\xb9\xca\xfeasC7\x96b\xd6v\xe4*\xc1\xa6\xae\xd8|E\x86d\r\xc1\xe1y*\xc0\xf2\x85\xca\xcd\xb1\re1\x05Bm\x91\xa2\x8d\x1f\xe7\x11\x1d\x93Ie\xbc\x92'
        b'\xfc\x8f\xe1R,\xe5\xc9\x13\x19ek\tK\xdfv\xdb\x1b\x83\xac</\xb6{\xad\xd9\xa0\xea<B\xaa\xeaX\x8d\xe7\x05\x13\xc2Q\xe4\xc7\xac\x93R\x89!\x1d7\x9e\x12\xce\xbe\x04|\xdb\x05|\x8an\xd3\xa5\xdfj\x85\xbb'
        b'\x8fVxG\xc4\xe9\xe7\x15#r\xbb`\x83\xbd\x94\xe2\xfb\x93\xb8ha\x05\x94\xd4\x0e\xfd\x1c\x06\x91\xd0\xfd0&o\x8c3}`/;P\x05\x96\\\xab\xc7\x98YEW\xb5\x1d\xd0\xf2\x8c\xc4\xa1\x98\t\xdb$0\xe3\xe6'
        b'\xe5\xca\x82\x8e^\x18\xea\xf7\xf6\x80{h0\xf6\xfd\xc0sRMg\xff\xd4KT\xf9\x10PYkP\xaf\xd5w\x08\xe3\x1b\x1c\xbd\x01\xc7\tW\xb1\xe1+\xb1\xd1\x93\x15\x9e0\x10\xebT\x8a\x0f\xa4+\xa7\xc6\x99\x05\x95\x93'
        b'\x1f\x17x\x91bn\xc0\xfbn5\xff\xb1*2\xb7\xd6\xd1\x9b8\xab\xe2\xfe\xf6z\x94\xf2\xe5/\xe1\xc7\xc0m4h\x8e\xad\xd9g\x1d#\xe7\x86hP\x91\xe6\xb4F\xaa\xbd\xad\x9eD\x1b1\x03\xc0"\xdbu\xd2\x16\xbe\x9f'
        b's\n\x1b\x80\x04U\xc7\xff\xf7\x80\x80C/ c\xefWW\xfa\xbd\xaf\xe3K\x89\x9e\xf8N\xf0\xab\xfb\x0f\\J\xd6\x86\x8d\xe7\xaa\xa2WI\x93CA+A\xc5\xc0x\x80\x91C\x03u\xcef\xde\x0c\x0b+\xc7\x89\xf6\xb5'
        b'r\x92!\x0e\xcf\x87\xf1\xf0\xfe\xaa@\x1dDV:\x07{y\xa9\x82\xd1\x1a\x9f\xfe\xb6d\xa5\xd4\x13sM\xb4\x8ar\x1e\xf6p\x1b\x86om\x03\xe1k*\x1b\x9d\x04\x90\xe4\x02\xa1R\xd2\xedJ8\x90\x8d\xba\x95\xda\x01\xdb'
        b'EB\x98\xe1A\x7f\xe9y\xaf\xfa9i"\t\xda\x8c/\x9f{#s\xebP\xdex@\xf9S\xb7\xbd3\xc7:;\x04\x9b\x05DB(\xa9\xaeC\x97\xfa{\xeem\x8c\xffd\xd3#k\x8a\xa7?C\xf2\xe6\xc7.\xdeZ'
        b'\x81\xa2\xba_EHK\xaefK\xe2\xee4\xac8(E\xecW\xb4VK8\x16\xde\x07B#r\xe1t\x81\xdc1\xbdl\xf8\xf8\xb6iT\x97D.\x0ef\x9a\x94\x07\xf3\xdb\x90\xd1\x84\xc6\x85\xe87\xaa\xf4\xd8\xbd\xfd]'
        b'#\xbd\xdf\xd3\xe8&\xbe\xba\xd2]\x80\xfd.zCN\xfd\xe2\x89(\xd1\x12\xc2\x8e\x8d&\xc9>\x89\x1d\x1d\x03\x83\xb7*\x1e0dg&\x9bI\x08{#\xa1\x16\x03\x91v\xbeu\xa0\xdd\x00\xc7q\xd8\xc08\xfc`\x87\xe3'
        b'\x87%\xe1\x80\xac8R\xb0_3\xe4]s!q\xab\xafT|[\xd6\xfa\x1e\x18#\x96\xde\x15\x85\x8d\xa0\x133T\xa4&&\xbb\xae\xd7%v\xc0b%D\x91\x0bz\x13\x0b\xc0\x0fJ>P\xd6fg\xfc\x82\xa37\xee'
        b'\xd8\xce\xb7&\xa8$\xe0\xf9\xd6\xd0\xe3J\xaaA!\x11|\xe2DN\xf2\x7f\xf2\x19\x96)G\xe3\xc73Q\xcc\xf1|\xfd\xd72\xfdt\xe9\x0e\xe9?\n\x16iqNi\xf3\xbb$\xa1L\xe2\x9e+\x10,BC\xecd]'
        b"\xad\x02>\x0b\xa6>\x1b\xb8\xf0'\xcchQ\xcf6<9\xc66\x8f\x1e\xc6\xfcKn\xb0\xab;\xa1\xb4UA\x9c\x94i\x80\xe6\xe4\x18aG\xfe\x97@}_\xf0:E\xf8z#\x9d\xe3K\x1a\xfc\xf2\xcf'\x80\xf7\xecF"
        b'\r\xc4y\x93\x04C\xa6\xc3\xa9\xd0\x83\xda\xa8va\xb9\xabT^7?\x0e\xd6I\xc53\xa5\xf8h\xd8\x94L\xd2{\x8e\xb8)\x85\xd7)\xed\xa3x$eG"\xaf|\x89\xcf\x9b\x98U\r\x00/\x97>\x96\xd3\xf4\xaf\xa4'
        b'\x8e,\xad#Om\xf5\xe5vMHY\x80\xb4\xb9\xcc\x84\x93\xc0$_\xdf.G\xa0\x13\x86E)\xac\xae\xaeO~\x16\xce0\xce\xcfS\xdds\xe9\xc8\x90Nc\xb9#\x19+\xf3\xff\xd3\xedpE\xf7\x07\x9d\x89[uM'
        b'\xd3t\x8e\x90\r\xba1\xe8crAY][v2\xec\x8f\xa9\xbd\xc1\x1bT\x15p\xf0\xf6T\x7f>\x03\xd9\xf2\x04w\x19\xdb\xb5i\x95J~\x02 \xec\xbe\x18\xb7\x11\xc7\xd5g\\\xcd\x05`\x97|\xba\x90\x11\x0b>\xfc'
        b'\x0c\x9bn-\xf3\xc0\xe5W\xd3IB\x8fDZ\x9a\xeb\xb5\xc5~\xa6\xdc\xd4\x8fLe~G\x9fjS<\xf4,\xb9f \x97@\xab\xe7^p\xa3\x13`\x8f\x15\xa0\x90H\xd4\x1a\x94<\x17(\xa5\xe7\xd3\xf7\xf4vt('
        b'N\xf4\xecb\xae\x9e\x14\xf7`\xd6k\x12\xc9\x9f\x10\x1c\x9a5X\xa4%?h\x08R.q\xc4\xd3\xd1E\xa2\xe7\x00\xfe\x12nD\xdc\xa0\x88.\xccSd\xe8JfB9\xd4_+5\x98\xb4Z[Q\xf1\xdb(}K'
        b'+\x18\xe1\x84\x93\xd97!\xe8>\x0e\xe4O\xd6\xf0\xd6|Z\xd7o\xd3#\x9aUZ\x1a8\r\xcc\xdfq*Yl\xd7\x14\xc6\xb2!\x9e\x12X\x11\x9c\xb9q\xf9\x19t\xc4\xc7\r)\xea!\xcc\xefm\xa6\x8a\xc7%\xaa7'
        b'\xeeQ\x88\xf0x(\x98\x87\'\x862\xc6#W\xd1\xb8rj\nM\x86\xbf\xa3\x8e\x90\xddz\x83\x01\xb7\x92"\x0c\xb93!L6\xf9\x8a\xc4\xcaH"T\xe1\x03\xa1\xe5\xa9\xc6 \x08\x94\xed:\xe4\xa9\xe7Q\xa4\x82\xcb\xb8'
        b'\xf0\xf2\\\xbe\xb4\xd6k\xa1=\x06\xd7\xfd\xa8\xff\xf8\x87\xbd[v\xe0h\x12\x15\xcf\xdb\x05~\xa7\xb8\xad\xb3\x8c{\xc0u\x18r\\z\x0cw\xf8R\xe9\xcd\x19\x84|\xfd\xb6\xef\xfbJ\xa7\x17t`\x9d38\xde\xc5\xecF'
        b'\x81Y5b\x86\x18"\x1a\xad*\xd0\xc5\xab\xf76\x1d\xbe\x16_\xb7\xd8\x83\x95\x0f\x06\x8d\xae\xb7\xe4g\xa1p\x8b06\x91\xb6j5\x07\x04\x97\x9a\x80\x00&Z(D%\x06\n\xd3\xa5\xeb\x9a~\rU\x90l`)\xe0'
        b'\x17T\tS\x1d\xb3\xaf\x10Z\x11JP9\xa1>U\x1adC\xff\x88\xf4\xcb\xf9\xfftUE\xcd-\xd9A\xc1\x00\x18`\xbf\xab\x1a\xc3.\xe7uS\xfc8|\x901\xb8]s\xdd\x96\xfa\xd7\xe3\xc1+*\xcc\xcb\xfa\xdd'
        b't\x1e\xc59\x97\xed\x17\xda[U\xa3\xf7mN\x0e\xca\xb1w\xeb\xbekr\x96\x87\xfb(\x88\x06K\x92=\xcf\xd1zt\xcc\xc3\x12CT\x9d\xe7\xce\xdboo\\\x84\xd0\xbcXhp\xc5\xe5\xd5\x1e\xc7\x13\xe10\xfb\xefU'
        b"\x00\xc5\xfcE\xcc\xec\xb1\x8f\xf4\x9eQ\x11'\xf2\xeew\x89\xf4\x9fk\xdb\x0e\\\x03m\xd8\x19\xeba\xf5\x98s\x882\xa0\x9d>\xa9f\xa1\xb1l\xb4\xd9 <\x83\xd4\xf3 \x02\xd8=\xe5\xe8\x18E\xe2(IG\x11\x15\xd7"
        b'\xe2\x17\xad\x0e\x80\x13\xe4\x08p\xf6\x80x|Y\xf4\xf2`\x9d\x9f\xd7\xa4\x93\xa0^\x90\xce\xab\xc4zpX!Zm[\n\x08V\n\xba\x9c\x8ee\x11\xfa(na\x16\xb6\th\x9c\xf7\xc3\x03yo\x82F\xc3\xec\x03\xbe'
        b'p\x81xd(\xb1\xf0@a\xc7\xc4|\x81\xa6r#\xdc\x16\xf0~\xa3\xf6#\xb7\xb6\xab\xa8(\x19\x7fp:\xcbs\x99p\xbb\x13\xb9\xec\x91J1\x83\xca\xf7y\x12\xf2o\x8e\xcf+\x9b5\xb5Z)\xde)\x94=|V'
        b'\x91,\xa2+S\xbd\xaa\xcd\xf5\x99!\xc9\xf6\x19\xfa\x90\x90M\x9f\x82h[\xd9\xf9\x1fz\xf7\xe2g\xf6\xd71\xe0=A\xb4\x0c\x1b\x98\x15!.\xa0o\xc8p\xe1\x9d#\x9a+\n\xf7\xc2\xf4\x8eU\xce\xa2p\xe0W\xd8\xee'
        b'\x83\xe7\xfd\xcd\xc2\xe5Y\xff\xbf\x02iX/.(\x1fD\xdf\xb1j\xb0\xd0\x184\xc1\xf3h2\x04\xd2#\xdaH\x86\xe7S\x10\xe63@\x8co\x18h\x9d\xef:\n\xf4\xd3\n%\x1a@\x9fO\x14\xd0m\x93\xc2\xf2z\x9b'
        b'~<[\x00[\xd5\x9f\xda\xbd\xc0Q\xb1\x1dC8\xaa\xc1\xba|\xad\xeaL9\xe6\xd0\xde\xf6o^\xe0\x18\x9e\x96\xa0\x16_/o\xf9\xa1\xe7*\x1f)_G\x04@\xe8\x83\xaf\x84\x07\xa4m\x07\xbc\x80@\xa7\n\x9f\x16U'
        b'i(q \x15S1|\x18\xd3,\xef4\xa2\xc0\xcbu\rb\xe5\xa4$z\xde!\x10q\xce\xc1\x92\xdf\x17\xa4\x04\xd3\x862\x15\x8a6g\x81>\xc9*\x9d\xebSh\xde\x1c\xaf\xb8\xe3\xac\x05\xa1{=\x99H\xd8\x85s'
        b'G\xab*v-\xf2\x04\x14 \x8c\xb5\x01\xdd\xd5\xda\x0ft\x86\xcb7\xbf>\xcc\x89\xe0I#\x07\xfd\x1b\xe8y\x8a\xc7\x14\x15\x04\x87\xab\x9a\xa2>\xfe1\n_"d\x8c\xa6\x91:s8\xa9\xe6\x0cw\xfd\xb3\xa2\\\xa7\xf8'
        b'\xc8>\xfbr\x1b\xa3\x98\xf7E\xdc\x97\xaahX/\xef31\x1aH\xe0\xfc\x8dA\xe3Lx\xf5\x9f\xf6\xd0\x99\xdcQ^4t\x8f\x1d\xdb|+\x12\x82\xde \xf4\x85\xe6\x02q-\\\xcb%\xc3\xe1;dwC\x8e\x81\xc8'
        b"\xe9o\x87\x98\xe8~G'\x91\xf8\xc7\xa8\x86\x1f5j\xd8\xc2t/\xed\\\x03\xd0\xacbT\x1e\x9e\xf9U\x7fLQ\x1f\x02.Q\xc3Q%\x81\xdf\xfa\xa08\xcc\xf1\xb0l\xcc\xf2\xfe?Ul\xf4\x19Y(\x97\xd8Sf"
        b'\xeb~\xe4G\x94m\x96\\i\xbf}\xffZnO\x85\x87$e8\xc4\xa9G\x0f\xdd[l\xbd\xb6\xdc\xa5n7\xe9D3Ljz\xbd\x13\x9c\xf5\x8d$\xf7Q(n\x9cz\x07\xf1\xc5\x86(\x86\x0f7S\xc756}'
        b"\x97\xd0\x97\xf5:c\xfe\x13*\x0e\x85o\x88m\xc6\xedb/\x9f\xca\x87\x1d\xe0\xa3\x89\xcf\x9e\xc5\xb4gy~\xae\xd9\xbb\x92\xd7\xabb\xc4l\x8b\x8bM\xfc(P\xb0@\x05q\x9b\xdaU\xc6|F\xca\xae\x13\x9c\xc7M'"
        b'[6\x8d!\xfe\x80ie\xef\xe3\x85c\x92\r\xb5\xc2I,0\xfb\xe8j\xf81\xacy\x89\xf8\xbe\xe2\x8e\xba|\x17\x17\x94\x01\xff\xde\x87(Y:\xc1\x83T<\x7f\xb7\xd6W?\n\xcf\x11\xb4\xe8\x85\xc9\xf9u\xb2De'
        b"6\x0fC\xe7\xe1\xee9-t\x88\x0f\xbeX\x9b]\x12\xe3\xbaD\x1a\x14\x05\xa5\x82>UN\n\xe7\x0fC\xbf\x1bx\xfe3_\xa6\xcbp\xc4\xf5\xee\xd6\x9d\xfe4\xccN\xd1\x9fu\x19=Y\x98'z1\xdbw#\x8f\x04"
        b'\xd4Rt\xad\xd1\x00\x8c\x81\xac\x19Qw\xb2B\xc6D\x1a9\xa0\x11.\xd7E\x0b\x99n<\xcd"\xcb\xaf\x14\xf1\x98\xb9\x9b\xda\x9c;\x91\xd1\xe2D_\xe0\x94\xe3}\xe4Zq\\\xcb\xb6\xee\x7f\x17\xdd+\xcf\xb0\xbb\xe3\xaf'
        b'\xc1\'D\xccZ\xe0$\xaa=/s\xcd\x9aa\\=\xf6\xec\x0eG\xb4\xady~\\\xe7\x17\xdf\xfa\xf8\x1c\x17\x8a\xe7\xaa\x8f]"\x16\xaek!\xefy\xb8\xb53\xb6\x0b\xac\x19\xab\xfd\xdeu\x9a\xb7\xa0\xf9v\x1d03\x92'
        b'\xf9iN\x8fh\x99J*.\xd3\x17\x9fY\xf7\xa9\xdb\xb0\x99\xe1\x89\tS|\x8e=\x8b\xa5\x81\x8c=xQ\xb4\xe2_\xab!\x86\x9fe2c9\xf1\xbb\xf0\xc9d\xd5\xcdAI\xa1\x08\xe0\x8f\xdd\x0b\x90?wi\xb3\xbb'
        b"4\xf2,\xe0\x18\x01\xe6\xd2\x8f\xff\xf0\xb0-\x82b\xe1!\x81\xd7\xef*`\xaa;WY\xc6\xbaL\xbb\x06\x86\x12y\xfe%\xb6\xf75\xe5\xb0\xc8\t'0\x81PNY\xc0ok\xdc\x01SK=\x9eZ\xc9\xe5\x17\xab\x7f"
        b'\x97\xf2`?\x9eY(d \xd7O\x88!\x10sT\xb7\x93\xc3\xeb\n\xd3I&\xf6u#-\xf1/\x80\x02\xc5_\xf8\xff)\xaf?\x92\xd6\x12\x90\x9f\xe8\x87\xbf\x84\x86?F\x83P\xd8\x14\xbb\xbb4\xf0\x19\xed\x01\xeaa'
        b"7\xa4\xc6J[U\xfa\x01p\xab\x83;\x94\xfa\xa0\xf1\x92\xfb\x17\x88\xdc%\x90\x02c/\xa3\x10w\x82\xaf\xe9Q\x0b\xc0\xbf\x12\x11\rP\xe6\xdcZb-P\x8d%\x7f\xbd\xe7'\x0e\x8a\\\x9b\x98\xd3\xe2\t\xcc\xe9\x01\x00"
        b'\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00'
        b'\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x06\x00\x00\x00\n\x00\x0e\x01\x12\x01'
    ))
